#
# Zsolt Keszthelyi, Jan 2022 - calculate cut-off B-field strengths
#
import numpy as np
import sys
import math
import glob, os

#----------------------------------------------

def allmodels(Zinin,brake,mix):

    #==== MODELS ====
    Zini = str(int(Zinin*1e3))
    Bpini = [250, 500, 750, 1000, 1500, 2000, 2500, 3000, 3500, 4000, 4500, 5000, 5500, 6000, 6500, 7000, 7500, 8000, 8500, 9000, 9500, 10000, 15000, 20000, 30000, 50000]

    mod = ['3.0','4.0','5.0','6.0','7.0','8.0','9.0','10.0','11.0','12.0','13.0','14.0','15.0','16.0','17.0', '18.0', '19.0', '20.0', '21.0', '22.0','23.0','24.0','25.0', '30.0', '40.0', '50.0', '60.0']
    path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+brake+'/Z'+Zini+mix+'/' #+Bpini+'/'
    mes = '/LOGS/out.data'
    #==== MODELS ====
    num = len(mod)

    # will write to these files
    something = open("eval/data/bco"+Zini+brake+mix+".txt","w")
    something2  = open("eval/data/vslow"+Zini+brake+mix+".txt","w")

    masses = []
    bco = []

 # ====================================   
 # === FOR N enrichment ===   
  # ====================================    
 # loop through all masses in a subgrid:
    for i in range(0,num) : 
  # loop through B-field strengths:
     for j in range(0,len(Bpini)):
      Bpinin = str(int(Bpini[j]))
      data = np.genfromtxt(path+Bpinin+'/'+mod[i]+mes,skip_header=6)  
     #----------------------------------------------
      coreh = data[:,59]
      xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
      x = len(xd)
      M = data[x:,2]
      logsurfh1 = data[x:,69]
      surfh1 = pow(10,logsurfh1)
      nit = data[x:,66] # N14
      lognit = np.log10(nit/(14*surfh1)) + 12.0 # "spectroscopic definition"
      #Beq = data[x:,85]
      #Beq_ZAMS = Beq[0]
      lognit_ZAMS = lognit[0]
      lognit_TAMS = lognit[-1] 
      #print lognit_TAMS-lognit_ZAMS, M[0]

# define "no enrichment" as: 
      if lognit_TAMS-lognit_ZAMS < 0.1 :
         #print 'condition met, no enrichment'
         #print Bpinin, int(M[0]), brake, mix, Zini
         
         massesx = str(int(M[0]+1.))
         bcox = str(int(Bpini[j-1]))  # -1 added to count the last element that would be above 0.1 dex.
         print(massesx, bcox)
         something.write(massesx+"   "+bcox+" \n") 

         # break is ok so long as we proceed in order of increasing B-field strength.
         break

# In some surf models even 50kG is not enough to quench mixing, so: 
      if Bpini[j] == 50e3 and lognit_TAMS-lognit_ZAMS > 0.1 :
         massesx = str(int(M[0]+1.))
         bcox = str(int(60000)) #str(int(Bpini[j]))
         #print massesx, bcox
         something.write(massesx+"   "+bcox+" \n")        	 
         #continue 

     # save masses and cutoff field strengths 
     # masses.append(int(M[0]))
     # bco.append(Bpinin)
   # print masses
   # print bco  

    something.close()

 # ====================================   
 # === FOR V SLOW ===   
  # ====================================    
 # loop through all masses in a subgrid:
    for i in range(0,num) : 
  # loop through B-field strengths:
     for j in range(0,len(Bpini)):
      Bpinin = str(int(Bpini[j]))

      data = np.genfromtxt(path+Bpinin+'/'+mod[i]+mes,skip_header=6)  
     #----------------------------------------------
      coreh = data[:,59]
      xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
      x = len(xd)
      M = data[x:,2]
      vrot = data[x:,22] 
      #Beq = data[x:,85]
      #Beq_ZAMS = Beq[0]

# define "slow rotation" as: 
      if vrot[-1] * math.sin(math.radians(45)) < 50 :
         #print 'condition met, no enrichment'
         #print Bpinin, int(M[0]), brake, mix, Zini
         
         massesx = str(int(M[0]+1.))
         bcox = str(int(Bpini[j]))
         #print massesx, bcox
         something2.write(massesx+"   "+bcox+" \n") 

         # break is ok so long as we proceed in order of increasing B-field strength.
         break
      
      if Bpini[j] == 50e3 and vrot[-1] * math.sin(math.radians(45)) > 50 :
         massesx = str(int(M[0]+1.))
         bcox = str(int(60000)) #str(int(Bpini[j]))
         #print massesx, bcox
         something2.write(massesx+"   "+bcox+" \n")           
         #continue 

    something2.close()

if __name__=="__main__":
    Z_list = np.array([0.002,0.006,0.014])
    for Zinin in Z_list:
     brake_list = ['SURF','INT']
     for brake in brake_list:	
      mix_list = ['Mix1','Mix2'] # Mix1, Mix2
      for mix in mix_list:
       #Bp_list = 1.e-3 * np.array([250, 500, 750, 1000, 1500, 2000, 2500, 3000, 3500, 4000, 4500, 5000, 5500, 6000, 6500, 7000, 7500, 8000, 8500, 9000, 9500, 10000, 11000, 12000, 13000, 14000, 15000, 20000, 30000, 50000])
       #for Bpinin in Bp_list:
         allmodels(Zinin,brake,mix)


