#
# Zsolt Keszthelyi, Jan 2022 - plot cut-off B-field strengths
#
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
from matplotlib.ticker import FormatStrFormatter
import numpy as np
import sys
import math
from pylab import *
from matplotlib.collections import PatchCollection
from matplotlib.patches import Rectangle
from matplotlib.collections import LineCollection
from matplotlib.ticker import AutoMinorLocator
#----------------------------------------------
# some constants
sigma = 5.67051 * pow(10,-5)  # cgs
Rsun = 6.957 * pow(10,10)
Lsun = 3.828 * pow(10,33)
pi = np.pi
G = 6.67259e-8 # cgs
Msun = 1.99e33  # cgs
year = 3.154e7  # sec. 
Teffsun = 5.780e3 # K 
loggsun = 4.43775 # cgs
#----------------------------------------------
#from Bco import *

#-------------------
# which metallicity? 
Zed = str(14)  # 14 6 2 
Zedi = '0.014' # 0.014 0.0064, 0.0026 
#-------------------

# ++++++++++++++++++++++++++++++++ SETUP PLOT HERE ++++++++++++++++++++++++++++++++
rc('axes', linewidth=10)
###rc('ticks', which = 'minor', width = 3, length = 12)
# =======================================================================================
# 
fig1, ax1 = plt.subplots(1,1, figsize=(20,10))
ax1.set_xlabel('M [M$_\odot$]', size=60 )
ax1.set_ylabel('log B$_{max, N}$ [kG]', size=60 )
ax1.tick_params(labelsize=54, width = 12, length = 22)
ax1.xaxis.set_major_locator(ticker.MultipleLocator(5)) # 2))
ax1.xaxis.set_minor_locator(AutoMinorLocator(5))
ax1.yaxis.set_minor_locator(AutoMinorLocator(5))
ax1.tick_params(which = 'minor', width = 3, length = 12)
ax1.set_title('N enrichment < 0.1 dex', fontsize = 60, fontweight='bold', pad = 40)
ax1.set_xlim(3,60)
ax1.set_ylim(-0.75,3.)

fig2, ax2 = plt.subplots(1,1, figsize=(20,10))
ax2.set_xlabel('M [M$_\odot$]', size=60 )
ax2.set_ylabel('log B$_{min, v}$ [kG]', size=60 )
ax2.tick_params(labelsize=54, width = 12, length = 22)
ax2.xaxis.set_major_locator(ticker.MultipleLocator(5)) # 2))
ax2.xaxis.set_minor_locator(AutoMinorLocator(5))
ax2.yaxis.set_minor_locator(AutoMinorLocator(5))
ax2.tick_params(which = 'minor', width = 3, length = 12)
ax2.set_title('$\mathbf{v_{rot}}$ at TAMS < 50 km s$\mathbf{^{-1}}$', fontsize = 60, fontweight='bold', pad = 40)
ax2.set_xlim(3,60)
ax2.set_ylim(-0.75,3.)

fig3, ax3 = plt.subplots(1,1, figsize=(20,14))
ax3.set_xlabel('M [M$_\odot$]', size=60 )
ax3.set_ylabel('log B$_{c.o.}$ [kG]', size=60 )
ax3.tick_params(labelsize=54, width = 12, length = 22)
ax3.xaxis.set_major_locator(ticker.MultipleLocator(5)) # 2))
ax3.xaxis.set_minor_locator(AutoMinorLocator(5))
ax3.yaxis.set_minor_locator(AutoMinorLocator(5))
ax3.tick_params(which = 'minor', width = 3, length = 12)
#ax3.set_title('Cutoff field strengths', fontsize = 60, fontweight='bold', pad = 40)
ax3.set_xlim(2.8,60.2)
ax3.set_ylim(-0.75,2.7)

fig4, ax4 = plt.subplots(1,1, figsize=(20,14))
ax4.set_xlabel('M [M$_\odot$]', size=60 )
ax4.set_ylabel('log B$_{c.o.}$ [kG]', size=60 )
ax4.tick_params(labelsize=54, width = 12, length = 22)
ax4.xaxis.set_major_locator(ticker.MultipleLocator(5)) # 2))
ax4.xaxis.set_minor_locator(AutoMinorLocator(5))
ax4.yaxis.set_minor_locator(AutoMinorLocator(5))
ax4.tick_params(which = 'minor', width = 3, length = 12)
#ax4.set_title('Cutoff field strengths', fontsize = 60, fontweight='bold', pad = 40)
ax4.set_xlim(2.8,60.2)
ax4.set_ylim(-0.75,2.7)


brake = ['INT','SURF']
mix = ['Mix1', 'Mix2']
# loop over the 4 schemes:
for i in range(0,2):
 for j in range(0,2):
  data1 = np.genfromtxt('eval/data/bco'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  mass = data1[:,0]
  bco = data1[:,1]
  lab = brake[i]+'/'+mix[j]
  #ax1.set_ylim(0,max(bco/1.e3)+1.)
  ax1.plot(mass,np.log10(bco/1.e3), lw = 13, linestyle = '-', zorder=2, label = lab)

for i in range(0,2):
 for j in range(0,2):
  data2 = np.genfromtxt('eval/data/vslow'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  mass = data2[:,0]
  bco = data2[:,1]
  lab = brake[i]+'/'+mix[j]
  #ax2.set_ylim(0,max(bco/1.e3)+1.)
  ax2.plot(mass,np.log10(bco/1.e3), lw = 13, linestyle = '-', zorder=2, label = lab)  

# COMBINED INT # 
for i in range(0,1):
#for i in range(1,2):
 for j in range(0,2):
  k = ['red','blue']
  #k = ['green', 'red']   
  data1 = np.genfromtxt('eval/data/bco'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  data2 = np.genfromtxt('eval/data/vslow'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  mass = data1[:,0]
  bcoN = data1[:,1]
  bcov = data2[:,1]
  lab = brake[i]+'/'+mix[j]
  #ax2.set_ylim(0,max(bco/1.e3)+1.)
  x = np.arange(3., 60., 0.01)
  incr = (60e3-250)/len(x)
  ax3.plot(mass,np.log10(bcoN/1.e3), lw = 12, color = k[j], linestyle = '-', zorder=10-j, label = lab)  
  ax3.plot(mass,np.log10(bcov/1.e3), lw = 12,  color = k[j], linestyle = '--', zorder=10-j) #, label = lab)  
  ax3.fill_between(mass,np.log10(bcov/1.e3), np.log10(bcoN/1.e3), where=bcoN/1.e3>=bcov/1.e3, interpolate=True, facecolor='red', zorder=10-j, color = k[j], alpha = 0.8)
 
  for l in range(0,len(mass)-1):
   if bcoN[l]/1.e3==bcov[l]/1.e3 : 
      print(bcoN[l]/1.e3, bcov[l]/1.e3, mass[l])

# COMBINED SURF # 
#for i in range(0,1):
for i in range(1,2):
 for j in range(0,2):
  #k = ['blue','orange']
  k = ['orange', 'magenta']   
  data1 = np.genfromtxt('eval/data/bco'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  data2 = np.genfromtxt('eval/data/vslow'+Zed+brake[i]+mix[j]+'.txt', skip_header = 0)
  mass = data1[:,0]
  bcoN = data1[:,1]
  bcov = data2[:,1]
  lab = brake[i]+'/'+mix[j]
  #ax2.set_ylim(0,max(bco/1.e3)+1.)
  ax4.plot(mass,np.log10(bcoN/1.e3), lw = 12, color = k[j], linestyle = '-', zorder=10-j, label = lab)  
  ax4.plot(mass,np.log10(bcov/1.e3), lw = 12,  color = k[j], linestyle = '--', zorder=10-j) #, label = lab)  
  ax4.fill_between(mass,np.log10(bcov/1.e3), np.log10(bcoN/1.e3), where=bcoN/1.e3>=bcov/1.e3, facecolor='red', zorder=10-j, color = k[j], alpha = 0.8)
 # ax4.fill_betweenx(np.log10(bcoN/1.e3), mass, mass, where=bcoN/1.e3>=bcov/1.e3,facecolor='red', zorder=10-j, color = k[j], alpha = 0.7)


ax1.text(5, 2.7, "Z = "+Zedi, fontsize = 36, color = 'black')
#:legend = ax1.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='upper right', shadow=True, fontsize=34, handlelength = 2)
ax2.text(5, 2.7, "Z = "+Zedi, fontsize = 36, color = 'black') 
ax3.text(5, 2.4, "Z = "+Zedi, fontsize = 46, color = 'black')
ax4.text(5, 2.4, "Z = "+Zedi, fontsize = 46, color = 'black')
legend = ax2.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='upper right', shadow=True, fontsize=36, handlelength = 3)
legend = ax3.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='upper right', shadow=True, fontsize=36, handlelength = 3)
legend = ax4.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='upper right', shadow=True, fontsize=36, handlelength = 3)


fig1.tight_layout()
fig2.tight_layout()
fig3.tight_layout()
fig4.tight_layout()
fig1.savefig('eval/bco'+Zed+'.png')
fig2.savefig('eval/vslow'+Zed+'.png')
fig3.savefig('eval/combinedINT'+Zed+'.png')
fig4.savefig('eval/combinedSURF'+Zed+'.png')
