# Calculate MESA input mass fractions from Dopita+2019 average values.
#
# Zsolt Keszthelyi Sept 2021
#
import numpy as np
import sys
import math
#----------------------------------------------

# LMC 
# epsilon = 12 + log10(X/H) in number fraction 
# from Dopita et al. 2019 Table 5
LsHe = 10.94
LsC = 8.02
LsN = 7.15
LsO = 8.40
LsNe = 7.70
LsS = 6.93
LsCl = 4.89
LsAr = 6.17
LsMg = 7.19
LsCa = 6.02
LsSi = 7.11
LsFe = 7.33
LsNi = 5.90
Leps = np.array([LsHe ,LsC ,LsN,LsO ,LsNe,LsS ,LsCl ,LsAr,LsMg ,LsCa,LsSi ,LsFe ,LsNi])

# mass fraction of element *per hydrogen* ! 
# nuclei numbers converting number fraction to mass fraction
LsHe2 = 4 * 10**(LsHe-12.) 
LsC2 = 12 * 10**(LsC-12.) 
LsN2 = 14 * 10**(LsN-12.) 
LsO2 = 16* 10**(LsO-12.) 
LsNe2 = 20 * 10**(LsNe-12.) 
LsS2 = 32 * 10**(LsS-12.) 
LsCl2 = 34 * 10**(LsCl-12.) 
LsAr2 = 36 * 10**(LsAr-12.) 
LsMg2 = 24 * 10**(LsMg-12.) 
LsCa2 = 40 * 10**(LsCa-12.) 
LsSi2 = 28 * 10**(LsSi-12.) 
LsFe2 = 52 * 10**(LsFe-12.) 
LsNi2 = 56 * 10**(LsNi-12.) 
Lsmh = np.array([LsHe2 ,LsC2 ,LsN2,LsO2 ,LsNe2,LsS2 ,LsCl2 ,LsAr2,LsMg2 ,LsCa2,LsSi2 ,LsFe2 ,LsNi2])

# Force that 1 = X + Y + Z
LX = 1./(np.sum(Lsmh[0:]) + 1.)
# metal mass fractions
LZm = LX * Lsmh
# sum of metal fractions
LZ = np.sum(LZm[1:])
# adopt LY from LsHe
LY = LX*LsHe2

print '===--------------==='
print 'LMC LX, LY, LZ, 1-X-Y, He, C, N, O: '
print LX, LY, LZ, 1.-LX-LY, LZm[0],LZm[1], LZm[2], LZm[3]
print '===--------------==='

# required MESA input 
Lmesa = LZm[1:]/LZ
print '===--------------==='
print 'MESA INPUT'
print 'C, N, O, Ne, S, Cl, Ar, Mg, Ca, Si, Fe, Ni'
print Lmesa[0],Lmesa[1],Lmesa[2],Lmesa[3],Lmesa[4],Lmesa[5],Lmesa[6]
print Lmesa[7],Lmesa[8],Lmesa[9],Lmesa[10],Lmesa[11]
print 'their sum'
print np.sum(Lmesa[0:])
print '===--------------==='


# SMC 
# epsilon = 12 + log10(X/H) in number fraction 
# from Dopita et al. 2019 Table 6
SsHe = 10.92
SsC = 7.38 
SsN = 6.81   
SsO = 8.05  
SsNe = 7.25
SsS = 6.48
SsCl = 4.45
SsAr = 5.77
SsMg = 6.72
SsCa = 5.77
SsSi = 6.75
SsFe = 6.77
SsNi = 5.55
Seps = np.array([SsHe ,SsC ,SsN,SsO ,SsNe,SsS ,SsCl ,SsAr,SsMg ,SsCa,SsSi ,SsFe ,SsNi])

# mass fraction of element *per hydrogen* ! 
# nuclei numbers converting number fraction to mass fraction
SsHe2 = 4 * 10**(SsHe-12.) 
SsC2 = 12 * 10**(SsC-12.) 
SsN2 = 14 * 10**(SsN-12.) 
SsO2 = 16* 10**(SsO-12.) 
SsNe2 = 20 * 10**(SsNe-12.) 
SsS2 = 32 * 10**(SsS-12.) 
SsCl2 = 34 * 10**(SsCl-12.) 
SsAr2 = 36 * 10**(SsAr-12.) 
SsMg2 = 24 * 10**(SsMg-12.) 
SsCa2 = 40 * 10**(SsCa-12.) 
SsSi2 = 28 * 10**(SsSi-12.) 
SsFe2 = 52 * 10**(SsFe-12.) 
SsNi2 = 56 * 10**(SsNi-12.) 
Ssmh = np.array([SsHe2 ,SsC2 ,SsN2,SsO2 ,SsNe2,SsS2 ,SsCl2 ,SsAr2,SsMg2 ,SsCa2,LsSi2 ,SsFe2 ,SsNi2])

# Force that 1 = X + Y + Z
SX = 1./(np.sum(Ssmh[0:]) + 1.)
# metal mass fractions
SZm = SX * Ssmh
# sum of metal fractions
SZ = np.sum(SZm[1:])
# adopt LY from LsHe
SY = SX*SsHe2

print '===--------------==='
print 'SMC SX, SY, SZ, 1-X-Y, He, C, N, O: '
print SX, SY, SZ, 1.-SX-SY, SZm[0],SZm[1], SZm[2], SZm[3]
print '===--------------==='

# required MESA input 
Smesa = SZm[1:]/SZ
print '===--------------==='
print 'MESA INPUT'
print 'C, N, O, Ne, S, Cl, Ar, Mg, Ca, Si, Fe, Ni'
print Smesa[0],Smesa[1],Smesa[2],Smesa[3],Smesa[4],Smesa[5],Smesa[6]
print Smesa[7],Smesa[8],Smesa[9],Smesa[10],Smesa[11]
print 'their sum'
print np.sum(Smesa[0:])
print '===--------------==='

# MESA option 8 for Abundances are abased on Asplund, Grevesse, Sauval, and Scott 2009, 
# but that of the some key elements are updated based on:
 #        ! "Present-day cosmic abundances ..." 
 #           ! by Nieva, M.-F. & Przybilla, N. 2012, A&A, 539, 143 
 #        ! and the proceeding paper
 #           ! "Hot Stars and Cosmic Abundances" by
 #           ! Przybilla N. Nieva M. F., Irrgang A. and Butler K. 2013, EAS Publ. Ser.
 #         ! The modified abundances w.r.t. A09 are (eps_El = log(El/H)+12.0) 
 #           ! eps_He = 10.99
 #           ! eps_C  = 8.33
 #           ! eps_N  = 7.79
 #           ! eps_O  = 8.76
 #           ! eps_Ne = 8.09    ! Cunha et al. (2006) give 8.11
 #           ! eps_Mg = 7.56
 #           ! eps_Al = 6.30
 #           ! eps_Si = 7.50
 #           ! eps_S  = 7.14
 #           ! eps_Ar = 6.50
 #           ! eps_Fe = 7.52  

GsHe = 10.99
GsC = 8.33
GsN = 7.79   
GsO = 8.76  
# mass fraction of element *per hydrogen* ! 
# nuclei numbers converting number fraction to mass fraction
GsHe2 = 4 * 10**(GsHe-12.) 
GsC2 = 12 * 10**(GsC-12.) 
GsN2 = 14 * 10**(GsN-12.) 
GsO2 = 16* 10**(GsO-12.) 
GX = 0.72000 # adopted value 
GY = 0.26600
GZ = 0.01400

print '===--------------==='
print 'Solar/Galactic GX, GY, GZ, 1-X-Y, He, C, N, O: '
print GX, GY, GZ, 1.-GX-GY, GsHe2*GX, GsC2*GX, GsN2*GX, GsO2*GX
print '===--------------==='
