# 
# Script to create abundance plot in Paper IV.  
#
# Sarah Brands, 2022
#

import matplotlib.pyplot as plt
import mesaPlot as mp
import tulips
import matplotlib as mpl

maindir = "/Users/sarah/Dropbox/projects/wind_theory/mesa_models/"

plt.rcParams.update({'font.family':'Tahoma'})


which_mix = 'INTMix1'
profdir = maindir + which_mix + '/'# + 'prof_midMS_' + which_mix + '.data'
INT_1 = mp.MESA()
INT_1.loadHistory(f=profdir)

which_mix = 'INTMix2'
profdir = maindir + which_mix + '/'# + 'prof_midMS_' + which_mix + '.data'
INT_2 = mp.MESA()
INT_2.loadHistory(f=profdir)

which_mix = 'SURF_MIX1'
profdir = maindir + which_mix + '/'# + 'prof_midMS_' + which_mix + '.data'
SURF_1 = mp.MESA()
SURF_1.loadHistory(f=profdir)

which_mix = 'SURF_MIX2'
profdir = maindir + which_mix + '/'# + 'prof_midMS_' + which_mix + '.data'
SURF_2 = mp.MESA()
SURF_2.loadHistory(f=profdir)



model_list = [INT_1, INT_2, SURF_1, SURF_2]
abun_list = ['he4', 'c12', 'n14', 'o16']

nring = 1000

per_element_4panel = True



# fig, ax = plt.subplots(figsize=(6, 1))
# fig.subplots_adjust(bottom=0.5)

abun_offset = 12

minC = -4.4
maxC = -3.9
minN = -3.1
maxN = -2.09
minO = -3.5
maxO = -2.25

if abun_offset != 0:
    extra_label = ' + ' + str(int(round(abun_offset,0)))
    unit_label = '_units_obs'
    do_He_log = False
    minHe = 0.25
    maxHe = 10**-0.20
else:
    extra_label = ''
    unit_label = '_units_theory'
    do_He_log = True
    minHe = -0.60
    maxHe = -0.20

the_colormap = 'viridis'
# the_colormap = 'plasma'

if per_element_4panel:
    fig, ax = plt.subplots(1,4,figsize=(1.5*9.0,1.5*4.0), sharex=True, sharey=True)

    cbaxes = fig.add_axes([0.25*0+0.025, 0.10, 0.19, 0.04])
    cmap = the_colormap
    norm = mpl.colors.Normalize(vmin=minHe, vmax=maxHe)
    fig.colorbar(mpl.cm.ScalarMappable(norm=norm, cmap=cmap),
                 cax=cbaxes, orientation='horizontal', label=r'$n_{\rm He}/n_{\rm H}$')

    cbaxes = fig.add_axes([0.25*1+0.025, 0.10, 0.19, 0.04])
    cmap = the_colormap
    norm = mpl.colors.Normalize(vmin=minC + abun_offset, vmax=maxC + abun_offset)
    fig.colorbar(mpl.cm.ScalarMappable(norm=norm, cmap=cmap),
                 cax=cbaxes, orientation='horizontal', label=r'log ($n_{\rm C}/n_{\rm H}$' + extra_label + ')')

    cbaxes = fig.add_axes([0.25*2+0.025, 0.10, 0.19, 0.04])
    cmap = the_colormap
    norm = mpl.colors.Normalize(vmin=minN + abun_offset, vmax=maxN + abun_offset)
    fig.colorbar(mpl.cm.ScalarMappable(norm=norm, cmap=cmap),
                 cax=cbaxes, orientation='horizontal', label=r'log ($n_{\rm N}/n_{\rm H}$' + extra_label + ')')

    cbaxes = fig.add_axes([0.25*3+0.025, 0.10, 0.19, 0.04])
    cmap = the_colormap
    norm = mpl.colors.Normalize(vmin=minO + abun_offset, vmax=maxO + abun_offset)
    fig.colorbar(mpl.cm.ScalarMappable(norm=norm, cmap=cmap),
                 cax=cbaxes, orientation='horizontal', label=r'log ($n_{\rm O}/n_{\rm H}$' + extra_label + ')')


    for i in range(len(model_list)):
        prof1 = tulips.property_profile(model_list[i], time_ind=63, property_name='he4', log=do_He_log, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=90*(i), theta2=90*(i+1), show_total_mass=False,
            show_time_label=False, hrd_inset=False,
            cmin=minHe, cmax=maxHe,
            cmap=the_colormap, fig=fig, ax=ax[0])
    for i in range(len(model_list)):
        prof1 = tulips.property_profile(model_list[i], time_ind=63, property_name='c12', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=90*(i), theta2=90*(i+1), show_total_mass=False,
            show_time_label=False, hrd_inset=False,
            cmin=minC, cmax=maxC,
            cmap=the_colormap, fig=fig, ax=ax[1])
    for i in range(len(model_list)):
        prof1 = tulips.property_profile(model_list[i], time_ind=63, property_name='n14', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=90*(i), theta2=90*(i+1), show_total_mass=False,
            show_time_label=False, hrd_inset=False,
            cmin=minN, cmax=maxN,
            cmap=the_colormap, fig=fig, ax=ax[2])
    for i in range(len(model_list)):
        prof1 = tulips.property_profile(model_list[i], time_ind=63, property_name='o16', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=90*(i), theta2=90*(i+1), show_total_mass=False,
            show_time_label=False, hrd_inset=False,
            cmin=minO, cmax=maxO,
            cmap=the_colormap, fig=fig, ax=ax[3])

    for anax in ax:
        # anax.set_xticks([])
        # anax.set_yticks([])
        # anax.set_xticklabels([])
        # anax.set_yticklabels([])
        anax.axis('off')
        anax.set_xlim(-21,21)
        anax.set_ylim(-21,21)

    thefs = 10
    theval1 = 10
    theval2 = 12
    ax[0].text(theval1,theval2,'INT-\nMix1', color='white', ha='center', va='center', size=thefs)
    ax[1].text(theval1,theval2,'INT-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[2].text(theval1,theval2,'INT-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[3].text(theval1,theval2,'INT-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[0].text(-theval1,theval2,'INT-\nMix2', color='white', ha='center', va='center', size=thefs)
    ax[1].text(-theval1,theval2,'INT-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[2].text(-theval1,theval2,'INT-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[3].text(-theval1,theval2,'INT-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[0].text(-theval1,-theval2,'SURF-\nMix1', color='white', ha='center', va='center', size=thefs)
    ax[1].text(-theval1,-theval2,'SURF-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[2].text(-theval1,-theval2,'SURF-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[3].text(-theval1,-theval2,'SURF-\nMix1', color='black', ha='center', va='center', size=thefs)
    ax[0].text(theval1,-theval2,'SURF-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[1].text(theval1,-theval2,'SURF-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[2].text(theval1,-theval2,'SURF-\nMix2', color='black', ha='center', va='center', size=thefs)
    ax[3].text(theval1,-theval2,'SURF-\nMix2', color='white', ha='center', va='center', size=thefs)
    ax[0].set_title('Helium', size=12)
    ax[1].set_title('Carbon', size=12)
    ax[2].set_title('Nitrogen', size=12)
    ax[3].set_title('Oxygen', size=12)



            #, cmin=-2, cmax=0)
    # tulips.property_profile(m11, time_ind=the_time, property_name='c12', log=True, num_rings=nring,
    #     show_colorbar=False, show_surface=False, theta1=-90, theta2=0, fig=fig, ax=theax, show_total_mass=False,
    #     show_time_label=True, cmin=-4.5, cmax=-2.)
    # tulips.property_profile(m11, time_ind=the_time, property_name='n14', log=True, num_rings=nring,
    #     show_colorbar=False, show_surface=False, theta1=0, theta2=90, fig=fig, ax=theax, show_total_mass=False,
    #     show_time_label=True, cmin=-4.5, cmax=-2.)
    # theax.text(-13.0, 0.0, r'$D_{\rm MIX}$', fontsize=9, color='white', ha='center', va='center')
    # theax.text(10.0, 10.0, r'N', fontsize=9, color='white', ha='center', va='center')
    # theax.text(10.0, -10.0, r'C', fontsize=9, color='white', ha='center', va='center')
    # theax.set_title(the_title, fontsize=10)
    plt.tight_layout()
    plt.savefig('../plots/abundance_mixing_schemes_' + unit_label + '.png', dpi=300)

plt.show()





















exit()

plot_carbon = True
plot_HHeCNO = True
plot_mixing = True
plot_mixing_nitro = True
plot_HHeCNO_time = True
plot_omega = False
plot_logj = False
plot_chem_profile = True

if plot_logj:

    fig, ax = tulips.property_profile(m11, time_ind=216, property_name='j_rot', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=0, theta2=120, show_total_mass=False,
        show_time_label=False,
        # cmin=0, cmax=0.4,
        cmin=11.5, cmax=19.0,
        hrd_inset=False)
    tulips.property_profile(m11, time_ind=126, property_name='j_rot', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=120, theta2=240, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False,
        # cmin=0, cmax=0.4,
        cmin=11.5, cmax=19.0,
        hrd_inset=False)
    tulips.property_profile(m11, time_ind=209, property_name='j_rot', log=True, num_rings=nring,
        show_colorbar=True, show_surface=False, theta1=240, theta2=360, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cbar_label=r'log J$_{\rm inside}$',
        # cmin=0, cmax=0.4,
        cmin=11.5, cmax=19.0,
        hrd_inset=False)
    ax.text(4.0, 12.0, 'ZAMS', fontsize=9, color='black')
    ax.text(5.0, -14.0, 'TAMS', fontsize=9, color='black')
    ax.text(-18.0, 0.0, 'mid\nMS', fontsize=9, color='black')
    ax.set_title(r'log J$_{\rm rot}$', fontsize=10)
    plt.savefig('../plots/logJ_evolution.png', dpi=300)

if plot_omega:

    fig, ax = tulips.property_profile(m11, time_ind=63, property_name='omega_div_omega_crit', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=0, theta2=120, show_total_mass=False,
        show_time_label=False,
        # cmin=0, cmax=0.4,
        cmin=-2.0, cmax=-0.6,
        hrd_inset=False)
    tulips.property_profile(m11, time_ind=126, property_name='omega_div_omega_crit', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=120, theta2=240, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False,
        # cmin=0, cmax=0.4,
        cmin=-2.0, cmax=-0.6,
        hrd_inset=False)
    tulips.property_profile(m11, time_ind=209, property_name='omega_div_omega_crit', log=True, num_rings=nring,
        show_colorbar=True, show_surface=False, theta1=240, theta2=360, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cbar_label=r'$\Omega / \Omega_{\rm crit}$',
        # cmin=0, cmax=0.4,
        cmin=-2.0, cmax=-0.6,
        hrd_inset=False)
    ax.text(4.0, 12.0, 'ZAMS', fontsize=9, color='white')
    ax.text(5.0, -14.0, 'TAMS', fontsize=9, color='white')
    ax.text(-18.0, 0.0, 'mid\nMS', fontsize=9, color='white')
    ax.set_title(r'$\Omega / \Omega_{\rm crit}$', fontsize=10)
    plt.savefig('../plots/omega_evolution.png', dpi=300)

if plot_HHeCNO:

    # fig, ax = tulips.property_profile(m11, time_ind=209, property_name='log_D_mix', log=True, num_rings=nring,
    #     show_colorbar=False, show_surface=False, theta1=0, theta2=72, show_total_mass=False, cmap = 'viridis',
    #     show_time_label=False, cmin=3, cmax=16)
    fig, ax = tulips.property_profile(m11, time_ind=209, property_name='h1', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=0, theta2=72, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=0)
    tulips.property_profile(m11, time_ind=209, property_name='he4', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=72, theta2=144, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=0)
    tulips.property_profile(m11, time_ind=209, property_name='c12', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=144, theta2=216, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=0)
    tulips.property_profile(m11, time_ind=209, property_name='n14', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=216, theta2=288, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=0)
    tulips.property_profile(m11, time_ind=209, property_name='o16', log=True, num_rings=nring,
        show_colorbar=True, show_surface=False, theta1=288, theta2=360, fig=fig, ax=ax,
        show_time_label=True, cmin=-4.5, cmax=0, cbar_label='log Abundance')
        # show_time_label=True, cmin=-4.5, cmax=0, cbar_label=r'log $D_{\rm mix}$')
    # ax.text(10.0, 6.0, r'log $D_{\rm mix}$', fontsize=9, color='white')
    ax.text(10.0, 6.0, 'H', fontsize=9, color='white')
    ax.text(-4.0, 12.0, 'He', fontsize=9, color='white')
    ax.text(-15.0, 0.0, 'C', fontsize=9, color='white')
    ax.text(-4.0, -12.0, 'N', fontsize=9, color='white')
    ax.text(10.0, -6.0, 'O', fontsize=9, color='white')

    ax.set_title('Abundances at TAMS', fontsize=10)
    plt.savefig('../plots/HHeCNO_midMS.png', dpi=300)


if plot_carbon:

    fig, ax = tulips.property_profile(m11, time_ind=63, property_name='c12', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=0, theta2=120, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=-2.6, hrd_inset=False)
    tulips.property_profile(m11, time_ind=126, property_name='c12', log=True, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=120, theta2=240, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=-2.6, hrd_inset=False)
    tulips.property_profile(m11, time_ind=209, property_name='c12', log=True, num_rings=nring,
        show_colorbar=True, show_surface=False, theta1=240, theta2=360, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=-4.5, cmax=-2.6, hrd_inset=False)
    ax.text(4.0, 12.0, 'ZAMS', fontsize=9, color='white')
    ax.text(5.0, -14.0, 'TAMS', fontsize=9, color='white')
    ax.text(-18.0, 0.0, 'mid\nMS', fontsize=9, color='white')
    ax.set_title('Carbon abundance', fontsize=10)
    plt.savefig('../plots/carbon_evolution.png', dpi=300)


if plot_mixing:
    fig, ax = tulips.property_profile(m11, time_ind=126, property_name='log_D_mix', log=False, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=0, theta2=90, show_total_mass=False,
        show_time_label=False, cmin=3, cmax=16, cmap='viridis')#, cmin=-2, cmax=0)
    tulips.property_profile(m11, time_ind=126, property_name='log_D_conv', log=False, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=90, theta2=180, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=3, cmax=16, cmap='viridis')
    tulips.property_profile(m11, time_ind=126, property_name='log_D_ovr', log=False, num_rings=nring,
        show_colorbar=False, show_surface=False, theta1=180, theta2=270, fig=fig, ax=ax, show_total_mass=False,
        show_time_label=False, cmin=3, cmax=16, cmap='viridis')
    tulips.property_profile(m11, time_ind=126, property_name='am_log_D_ES', log=False, num_rings=nring,
        show_colorbar=True, show_surface=False, theta1=270, theta2=360, fig=fig, ax=ax,
        cmin=3, cmax=16, cbar_label=r'log D [cm$^2$ s$^{-1}$]', cmap='viridis')
    ax.text(10.0, 10.0, r'$D_{\rm MIX}$', fontsize=9, color='white', ha='center', va='center')
    ax.text(10.0, -10.0, r'$D_{\rm CONV}$', fontsize=9, color='white', ha='center', va='center')
    ax.text(-10.0, -10.0, r'$D_{\rm OV}$', fontsize=9, color='white', ha='center', va='center')
    ax.text(-10.0, 10.0, r'$D_{\rm ES}$', fontsize=9, color='white', ha='center', va='center')
    ax.set_title('Diffusion coefficients at mid-MS', fontsize=10)
    plt.savefig('../plots/diffusion_midMS.png', dpi=300)

if plot_mixing_nitro:
    fig, ax = plt.subplots(1,3,figsize=(1.5*10,1.5*6.0))
    the_time = 216
    for theax, the_time, the_title in zip((ax[0], ax[1], ax[2]),(63, 126, 216),('ZAMS', 'mid-MS', 'TAMS')):
        tulips.property_profile(m11, time_ind=the_time, property_name='log_D_mix', log=False, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=90, theta2=-90, show_total_mass=False,
            show_time_label=False, cmin=3, cmax=16, cmap='viridis', fig=fig, ax=theax)#, cmin=-2, cmax=0)
        tulips.property_profile(m11, time_ind=the_time, property_name='c12', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=-90, theta2=0, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=True, cmin=-4.5, cmax=-2.)
        tulips.property_profile(m11, time_ind=the_time, property_name='n14', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=0, theta2=90, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=True, cmin=-4.5, cmax=-2.)
        theax.text(-13.0, 0.0, r'$D_{\rm MIX}$', fontsize=9, color='white', ha='center', va='center')
        theax.text(10.0, 10.0, r'N', fontsize=9, color='white', ha='center', va='center')
        theax.text(10.0, -10.0, r'C', fontsize=9, color='white', ha='center', va='center')
        theax.set_title(the_title, fontsize=10)
    plt.tight_layout()
    plt.savefig('../plots/mixing_vs_abundance_' + the_title + '.png', dpi=300)

if plot_HHeCNO_time:
    fig, ax = plt.subplots(1,3,figsize=(1.5*10,1.5*6.0))
    for theax, the_time, the_title in zip((ax[0], ax[1], ax[2]),(63, 126, 216),('ZAMS', 'mid-MS', 'TAMS')):

        if theax == ax[2]:
            showcbar = False
        else:
            showcbar = False
        tulips.property_profile(m11, time_ind=the_time, property_name='h1', log=False, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=0, theta2=72, show_total_mass=False,
            show_time_label=False, cmin=-4.5, cmax=-0.1, fig=fig, ax=theax)#, cmin=-2, cmax=0)
        tulips.property_profile(m11, time_ind=the_time, property_name='he4', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=72, theta2=144, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=False, cmin=-4.5, cmax=-0.1)
        tulips.property_profile(m11, time_ind=the_time, property_name='c12', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=144, theta2=216, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=False, cmin=-4.5, cmax=-0.1)
        tulips.property_profile(m11, time_ind=the_time, property_name='n14', log=True, num_rings=nring,
            show_colorbar=False, show_surface=False, theta1=216, theta2=288, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=False, cmin=-4.5, cmax=-0.1)

        if theax == ax[2]:
            showcbar = False
        else:
            showcbar = False
        tulips.property_profile(m11, time_ind=the_time, property_name='o16', log=True, num_rings=nring,
            show_colorbar=showcbar, show_surface=False, cbar_label=r'log Abundacne', theta1=288, theta2=360, fig=fig, ax=theax, show_total_mass=False,
            show_time_label=False, cmin=-4.5, cmax=-0.1)

        theax.text(10.0, 6.0, 'H', fontsize=9, color='black')
        theax.text(-4.0, 12.0, 'He', fontsize=9, color='white')
        theax.text(-15.0, 0.0, 'C', fontsize=9, color='white')
        theax.text(-4.0, -12.0, 'N', fontsize=9, color='white')
        theax.text(10.0, -6.0, 'O', fontsize=9, color='white')
        theax.set_title(the_title, fontsize=10)
    plt.savefig('../plots/abundance_time.png', dpi=300)

if plot_chem_profile:
    isotope_list = tulips.get_isotopes(m11)
    fig, ax = plt.subplots(1,3,figsize=(10,6.0))

    tulips.chemical_profile(m11, time_ind=63, show_colorbar=False, show_ring_annotations=False, cmap='plasma', fig=fig, ax=ax[0])
    plt.rcParams.update({'font.size': 18})
    tulips.create_elem_colorbars(isotope_list, ax[0], cmap='plasma', max_cbar_elem=12, orientation='vertical')

    plt.rcParams.update({'font.size': 10})
    tulips.chemical_profile(m11, time_ind=126, show_colorbar=False, show_ring_annotations=False, cmap='plasma', fig=fig, ax=ax[1])
    plt.rcParams.update({'font.size': 18})
    tulips.create_elem_colorbars(isotope_list, ax[1], cmap='plasma', max_cbar_elem=12, orientation='vertical')

    plt.rcParams.update({'font.size': 10})
    tulips.chemical_profile(m11, time_ind=209, show_colorbar=False, show_ring_annotations=False, cmap='plasma', fig=fig, ax=ax[2])
    plt.rcParams.update({'font.size': 18})
    tulips.create_elem_colorbars(isotope_list, ax[2], cmap='plasma', max_cbar_elem=12, orientation='vertical')

    plt.subplots_adjust(bottom=0.0, top=1.0, left=0.01, right=0.99, wspace=0.01)
    plt.savefig('../plots/abundance_evolution.png', dpi=300)


plt.show()
