'''
This python script is used to read in MESA evolutionary files 
and create HRD, Kiel, and Hunter diagrams for the fiducial 20 Msun models,
 displayed in "Paper IV" by Keszthelyi et al. 

Have fun plotting, 
    Zsolt Keszthelyi, 2022
'''

import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
from matplotlib.ticker import FormatStrFormatter
import numpy as np
import sys
import math
from pylab import *
from matplotlib.collections import PatchCollection
from matplotlib.patches import Rectangle
from matplotlib.collections import LineCollection
from matplotlib.ticker import AutoMinorLocator
#----------------------------------------------
# some constanst and useful things
sigma = 5.67051 * pow(10,-5)  # cgs
Rsun = 6.957 * pow(10,10)     # cgs
Lsun = 3.828 * pow(10,33)     # cgs
pi = np.pi
G = 6.67259e-8 # cgs
Msun = 1.99e33  # cgs
year = 3.154e7  # sec. 
Teffsun = 5.780e3 # K 
loggsun = 4.43775 # cgs
Lscriptsun = pow(Teffsun,4.)/(10**loggsun)
#----------------------------------------------
#=========================================
from plotsetupfidu import *    # and plotsetup to some extent
#=========================================
#
#==== MODELS ==== (4 models in the present setup)
#:Bpinin = 3.0  # in kG
#:Bpini = ['3000','3000','3000','3000'] 
#:Zini = 0.014
#:Zin = '14'
#:mix = ['Mix1','Mix2','Mix1','Mix2'] # Mix1 or 'Mix2'
#:modi = 'mix'  # 'mix' #'scheme' # 'Z'
#mod = ['0','500','1000', '3000', '8000']
#mod = ['014', '0064', '0026']
#:mod = ['INT','INT','SURF','SURF']
#:lab = ['INT/Mix1','INT/Mix2','SURF/Mix1','SURF/Mix2']
#path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme+'/Z'  #+Zin+'Om5'+mix+'/' # +Bpini+'/'
path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'  #+scheme+  #+Zin+'Om5'+mix+'/' # +Bpini+'/'
#path = '../data/'+scheme+'/Z14'+mix+'/'+Bpini+'/'
#:::mes = '/Z'+Zin+'Om5'+mix[i]+'/'+Bpini+'/20/LOGS/out.data'

# this is for Appendix figure with varying B-field
Zini = 0.014
Zin = '14'
Bpinin = ['0', '0.25', '1.0', '10.0']
Bpini = ['0','250','1000','10000']
mix = ['Mix2','Mix2','Mix2','Mix2'] #['Mix1','Mix1','Mix1','Mix1']
scheme = ['NOMAG', 'SURF','SURF','SURF']  #['NOMAG', 'SURF','SURF','SURF'] # ['NOMAG', 'INT','INT','INT']
mod = scheme 
modi = 'Bp'
lab = ['0 kG', '0.25 kG', '1.0 kG', '10.0 kG']

# this is for Appendix figure with varying Z 
#:Zini = ['0.014','0.0064','0.0026']
#:Zin = ['14','6','2']
#:Bpinin = '1.0'
#:Bpini = ['1000','1000','1000']
#:mix = ['Mix1','Mix1','Mix1']
#:scheme = ['INT','INT','INT']
#:mod = scheme 
#:modi = 'Z'
#:lab = ['$Z = 0.014$', '$Z = 0.0064$', '$Z = 0.0026$']

num = len(mod)
kk = ['black','black','white','white','black']
k = ['red','blue','orange','magenta','green','yellow','blue','navy','grey','green','yellow','blue','navy','grey','green','yellow','blue','navy','grey','green','yellow','blue']
j = ['-',':','-.','--','-',':','--','-.','-','--','-.','-','--','-.']
lww = [6,6,6,12,12,12,18,18,18]

# This is for the colour bar:
def get_max_bar_value():
    m = 0
    for i in range(0,num):
        mes = '/Z'+Zin+mix[i]+'/'+Bpini[i]+'/60.0/LOGS/out.data'  # 20, 60 
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        vrot = data[x:,22]
        bar = vrot
        m_temp = bar.max()
        if m_temp > m:
            m = m_temp          
    return m
m = get_max_bar_value()
baz = m 

def get_min_bar_value():
    n = 1e33  #0
    for i in range(0,num):
        mes = '/Z'+Zin+mix[i]+'/'+Bpini[i]+'/60.0/LOGS/out.data'
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        vrot = data[x:,22]
        bar = vrot
        n_temp = bar.min()
        if n_temp < n:   # direction < for age, > for log g 
            n = n_temp          
    return n
n = get_min_bar_value()
meg = n 

def get_max_bar_values():
    mm = 0
    for i in range(0,num):
        mes = '/Z'+Zin+mix[i]+'/'+Bpini[i]+'/20.0/LOGS/out.data'
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        logg =  data[x:,14]
        bar = logg
        m_temp = bar.max()
        if m_temp > mm:
            mm = m_temp          
    return mm
mm = get_max_bar_values()
bazz = mm 

def get_min_bar_values():
    nn = 1e33
    for i in range(0,num):
        mes = '/Z'+Zin+mix[i]+'/'+Bpini[i]+'/20.0/LOGS/out.data'
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        logg =  data[x:,14]
        bar = logg
        n_temp = bar.min()
        if n_temp < nn:   # check
            nn = n_temp          
    return nn
nn = get_min_bar_values()
megg = nn 

print ('************************************************************')
print ('*   Thank you for plotting with python. Have a nice day.   *')
print ('************************************************************')

#print baz, bazz
#print meg, megg

# empty vectors for iso-s
logLzams = []
loggzams = []
Teffzams = []
vrotzams = []
lognzams = []
logLiso1 = []
loggiso1 = []
Teffiso1 = []
logLiso2 = []
loggiso2 = []
Teffiso2 = []
vrotiso2 = []
logniso2 = []

loggisox1 = []
loggisox2 = []
loggisox3 = []
Teffisox1 = []
Teffisox2 = []
Teffisox3 = []

loggiso3 = []
Teffiso3 = []
loggiso5 = []
Teffiso5 = []
loggiso4 = []
loggiso6 = []
loggiso8 = []
loggiso10 = []
Teffiso10 = []
loggiso20 = []
Teffiso20 = []

logLiso4 = []
Teffiso4 = []
logLiso6 = []
Teffiso6 = []
logLiso8 = []
Teffiso8 = []
logLiso10 = []
Teffiso10 = []
logLiso50 = []
Teffiso50 = []

vrotiso4 = []
logniso4 = []
vrotiso6 = []
logniso6 = []
vrotiso8 = []
logniso8 = []
vrotiso10 = []
logniso10 = []

##### MESA files input ###### 
for i in range(0,num) : 
 mes = '/Z'+Zin+mix[i]+'/'+Bpini[i]+'/60.0/LOGS/out.data'  # 20 
 data = np.genfromtxt(path+mod[i]+mes,skip_header=6)  
#-----------------------------------------------
 coreh = data[:,59]
 xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
 x = len(xd)

 model = data[:,0]
 m = len(model)
 age2 = data[x-1:m-1,1]
 age = data[x:,1]
 M = data[x:,2]
 logM = np.log10(M)
 Mdot = data[x:,3]
 Mdot = - Mdot 
 logMdot = np.log10(Mdot)
 logTeff = data[x:,6]
 Teff = data[x:,7]
 logL = data[x:,11]
 R =  data[x:,13]
 logg =  data[x:,14]
 g = 10**logg
 centernit = data[x:,62] # N14 core
 logsurfh1 = data[x:,69]
 surfh1 = pow(10,logsurfh1)
 nit = data[x:,66] # N14 surface
 ox = data[x:,67] # O16
 car = data[x:,65]  # C12
 lognit = np.log10(nit/(14*surfh1)) + 12 # spectroscopic def.
 logsurfhe = data[x:,70] # He4 surf
 surfhe = 10**logsurfhe
 
 nith = nit/surfh1
 oxh = ox/surfh1
 carh = car/surfh1

# core 
 czm = data[x:,27] *Msun
 czr = data[x:,28] *Rsun
 czo = data[x:,29] 
 czj = 2./3. * czm * czr**2. * czo
 Jcore = czj
 #-- rot
 vrot = data[x:,22]
 Jtot = data[x:,5]
 Omega = data[x:,19]
 Omegac = data[x:,58]
 omdivomcr = data[x:,20]
 periods = 2. * pi * (R*Rsun) / (vrot *1e5)
 period = periods / (3600. * 24.)
 logperiod = np.log10(period)

#-- mag 
 Bp = data[x:,85]
 logBp = np.log10(Bp)
 etastar = data[x:,88]
 Mdotorig = data[x:,96]
 logMdotorig = np.log10(Mdotorig)
 Jbrake = data[x:,95]
 Jsurf = data[x:,99]
 logJsurf = np.log10(Jsurf)
 RA = data[x:,89]    # this is R_A / R_star
 Rc = data[x:,90]
 gmr = G * (M*Msun) / (R*Rsun)   # cgs
 om2 = vrot*1.e5 / (R*Rsun) 
 Wpar = vrot*1.e5 / sqrt(gmr)    # cgs 
 yy = - (2./3.)
 RK = pow(Wpar,yy)    # this is R_K / R_star
 RA = np.log10(RA)
 RK = np.log10(RK)
#::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 time = age/pow(10,6)
 time2 = age2/pow(10,6)
#=========  END of MESA file input ==============================================================
 if max(Omegac/Omega) > 1: 
  ddx1 = Teff.compress(((Omegac/Omega)<1.).flat) #
  dax1 = len(ddx1)
  loggisox1.append(logg[dax1])
  Teffisox1.append(Teff[dax1]/1e3)

 if max(Omegac/Omega) > 2: 
  ddx2 = Teff.compress(((Omegac/Omega)<2.).flat) #
  dax2 = len(ddx2)
  loggisox2.append(logg[dax2])
  Teffisox2.append(Teff[dax2]/1e3)

 if max(Omegac/Omega) > 3: 
  ddx3 = Teff.compress(((Omegac/Omega)<3.).flat) #
  dax3 = len(ddx3)
  loggisox3.append(logg[dax3])
  Teffisox3.append(Teff[dax3]/1e3)

 dd1 = Teff.compress(((age/1e6)<2.).flat) # show 2 Myr
 da1 = len(dd1)
 dd2 = Teff.compress(((age/1e6)<4.).flat) # show 4 Myr
 da2 = len(dd2)
 dd3 = Teff.compress(((age/1e6)<6.).flat) # show 6 Myr
 da3 = len(dd3)
 dd4 = Teff.compress(((age/1e6)<8.).flat) # show 8 Myr
 da4 = len(dd4)
 dd5 = Teff.compress(((age/1e6)<10.).flat) # show 10 Myr
 da5 = len(dd5)
 dd50 = Teff.compress(((age/1e6)<50.).flat) # show 50 Myr
 da50 = len(dd50)

 logLzams.append(logL[0])
 Teffzams.append(Teff[0]/1e3)
 vrotzams.append(vrot[0])
 loggzams.append(logg[0])
 lognzams.append(lognit[0])

 logLiso2.append(logL[da1])
 Teffiso2.append(Teff[da1]/1e3)
 vrotiso2.append(vrot[da1])
 loggiso2.append(logg[da1])
 logniso2.append(lognit[da1])
 
 if max(age/1e6) > 4: 
  logLiso4.append(logL[da2])
  Teffiso4.append(Teff[da2]/1e3)
  vrotiso4.append(vrot[da2])
  loggiso4.append(logg[da2])
  logniso4.append(lognit[da2])
 if max(age/1e6) > 6 :
  logLiso6.append(logL[da3])
  Teffiso6.append(Teff[da3]/1e3)
  vrotiso6.append(vrot[da3])
  loggiso6.append(logg[da3])
  logniso6.append(lognit[da3])
 if max(age/1e6) > 8 :
  logLiso8.append(logL[da4])
  Teffiso8.append(Teff[da4]/1e3)
  vrotiso8.append(vrot[da4])
  loggiso8.append(logg[da4])
  logniso8.append(lognit[da4])
 if max(age/1e6) > 10 :
  logLiso10.append(logL[da5])
  Teffiso10.append(Teff[da5]/1e3)
  vrotiso10.append(vrot[da5])
  loggiso10.append(logg[da5])
  logniso10.append(lognit[da5])
 if max(age/1e6) > 50 :
  logLiso50.append(logL[da50])
  Teffiso50.append(Teff[da50]/1e3)

# remember to swap elements to show isochrones correctly not in zigzag from track to track. 

 Mini = "{:1.0f}".format(M[0])
# ---  Bpinin = "{:1.0f}".format(Bp[0])

#
# === IN LOOP PLOTS ===    
#

# HRD
 ax1.plot(Teff/1e3, logL, lw = 18, linestyle = j[i], color = k[i], zorder=4+i, label = lab[i])
#--- ax1.text(Teff[0]/1e3 + 1.8, logL[0] - 0.12, Mini, fontsize = 16)
#::: ims1 = ax1.scatter(Teff/1e3, logL,c= vrot, marker='o', edgecolors='none', s=700, cmap=plt.cm.gnuplot2, vmin = meg, vmax = baz, zorder = 3)

 # KIEL 
 ax111.plot(Teff/1e3, logg, lw = 18, linestyle = j[i], color = k[i], zorder=4+i, label = lab[i])
#::: ims111 = ax111.scatter(Teff/1e3,logg,c= vrot, marker='o', edgecolors='none', s=700, cmap=plt.cm.gnuplot2, vmin = meg, vmax = baz, zorder=3)
 #::ax111.plot(Teff[da3]/1e3, logg[da3], linestyle = '', marker = 'X', markersize = 32, color = 'yellow', zorder=5)

 #ax111.text(Teffiso10[-1]+4., loggiso10[-1], '$\Omega_{core}/\Omega_{surf} = 10$', color  = 'grey', fontsize = 16)
 #ax111.text(Teffiso20[-1]+4., loggiso20[-1], '$\Omega_{core}/\Omega_{surf} = 20$', color  = 'grey', fontsize = 16)

# HUNTER 
 ax3.plot(vrot, lognit, lw=14, linestyle = j[i], color = 'black', zorder = 31, label = lab[i])
 ims3 = ax3.scatter(vrot, lognit,c= logg, marker='o', edgecolors='none', s=1500, cmap=plt.cm.gist_rainbow, vmin = megg, vmax = bazz, zorder = 30 - i)
 
 # Mass
 ax4.plot(time, M, lw=4, linestyle = j[i], color = kk[i], zorder = 31, label = lab[i])
 ims4 = ax4.scatter(time, M,c= vrot, marker='o', edgecolors='none', s=900, cmap=plt.cm.gnuplot2, vmin = meg, vmax = baz, zorder = 30 - i)
 
 #:::ax3.text(vrot[-1] - 25, lognit[-1], Mini, fontsize = 16)

# === out of loop isos ===

# need to sort element order: 

Teffiso2.sort()
Teffiso4.sort()
Teffiso6.sort()
Teffiso8.sort()
Teffiso10.sort()

logLiso2.sort()
logLiso4.sort()
logLiso6.sort()
logLiso8.sort()
logLiso10.sort()

loggiso2.sort()
loggiso4.sort()
loggiso6.sort()
loggiso8.sort()
loggiso10.sort()

 # isos on HRD 
ax1.plot(Teffzams, logLzams, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax1.plot(Teffiso2, logLiso2, lw = 6, linestyle = '-', color = 'grey', zorder = 11)
ax1.plot(Teffiso4, logLiso4, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax1.plot(Teffiso6, logLiso6, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax1.plot(Teffiso8, logLiso8, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax1.plot(Teffiso10, logLiso10, lw = 2, linestyle = '-', color = 'grey', zorder = 11)
#--ax1.plot(Teffiso50, logLiso50, lw = 2, linestyle = '-', color = 'grey', zorder = 11)

 # isos on Kiel
ax111.plot(Teffzams, loggzams, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax111.plot(Teffiso2, loggiso2, lw = 6, linestyle = '-', color = 'grey', zorder = 11)
ax111.plot(Teffiso4, loggiso4, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax111.plot(Teffiso6, loggiso6, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax111.plot(Teffiso8, loggiso8, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax111.plot(Teffiso10, loggiso10, lw = 2, linestyle = '-', color = 'grey', zorder = 11)

 # isos on Hunter
ax3.plot(vrotzams, lognzams, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax3.plot(vrotiso2, logniso2, lw = 6, linestyle = '-', color = 'grey', zorder = 11)
ax3.plot(vrotiso4, logniso4, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax3.plot(vrotiso6, logniso6, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax3.plot(vrotiso8, logniso8, lw = 6, linestyle = '-',  color = 'grey', zorder = 11)
ax3.plot(vrotiso10, logniso10, lw = 2, linestyle = '-', color = 'grey', zorder = 11)

 # isos on Kiel

#:ax111.plot(Teffisox1, loggisox1, lw = 2, linestyle = '-', color = 'grey', zorder=11)
#:ax111.plot(Teffisox2, loggisox2, lw = 2, linestyle = '-', color = 'grey', zorder=11)

#---ax111.text(Teffisox1[-1] - 5., loggisox1[-1] + 0.1, r'$\frac{\Omega_{core}}{\Omega_{surf}} = 1$', color  = 'grey', fontsize = 36)


# COLOR BARS 

#--cbar = fig111.colorbar(ims111)
#--cbar.ax.tick_params(labelsize=54) 
#cbar.set_label('age [Myr]', size = 54)
#--cbar.set_label('$v_{rot}$ [km s$^{-1}$]', size = 54)

cbar = fig3.colorbar(ims3)
cbar.ax.tick_params(labelsize=54) 
cbar.set_label('log $g$ [cm s$^{-2}$]', size = 54)

cbar = fig4.colorbar(ims4)
cbar.ax.tick_params(labelsize=54) 
cbar.set_label('v$_{rot}$ [km s$^{-1}$]', size = 54)

# +++++++++++++++++++++++++++++++++++++++++++++++
# FINISH PLOTS:
# BOX and TEXT 
# +++++++++++++++++++++++++++++++++++++++++++++++

# for mix
#strg = '\n'.join(('$B_{p, ini} = $ %s kG', '$Z_{ini} = $ %s', r'$\frac{\Omega_{ini}}{\Omega_{crit, ini}}= 0.5$','SURF scheme', 'Mix1 scheme')) % (Bpinin, Zini)
# for Fig 6
#strg = '\n'.join(('','$M_{ini} = $ %s M$_\odot$', '$B_{eq, ini} = $ %s kG', '$Z_{ini} = $ %s', r'$\frac{\Omega_{ini}}{\Omega_{crit, ini}}= 0.5$')) % (Mini, Bpinin, Zini)  ##
# For Bp (mass plot)
strg = '\n'.join(('','$M_{ini} = $ %s M$_\odot$', '$Z_{ini} = $ %s', 'SURF scheme','Mix2 scheme', r'$\frac{\Omega_{ini}}{\Omega_{crit, ini}}= 0.5$')) % (Mini, Zini)  ##
#for Z
#strg = '\n'.join(('','$M_{ini} = $ %s M$_\odot$', '$B_{eq, ini} = $ %s kG', 'INT scheme','Mix1 scheme', r'$\frac{\Omega_{ini}}{\Omega_{crit, ini}}= 0.5$')) % (Mini, Bpinin)  ##

si = 46

ax1.text(29., 4.6, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = si, color = 'black')
ax111.text(43.,3.6, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = si, color = 'black')
# change this per plot.
#ax3.text(0.,8.8, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
#for mix:
#--- ax3.text(300.,8.55, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = si, color = 'black')
#ax4.text(0,55.3, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = si, color = 'black')
ax4.text(0,33, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = si, color = 'black')


# GALAXY:
#if Zini == 0.014 : 
# ax111.text(54., 2.6, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
# ax3.text(250, 8.55, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
# LMC:
#if Zini == 0.007 : 
# ax111.text(23., 2.95, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
# ax3.text(250, 8.05, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
# SMC:
#if Zini == 0.002 : 
# ax111.text(23., 3.5, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')
# ax3.text(250, 7.95, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')

# iso texts for GALAXY 
if Zini == 0.014 : 
 # HRD   
 ax1.text(36.5, 4.58, 'ZAMS', fontsize = si, color = 'grey')
 ax1.text(37., 4.66, '2 Myr', fontsize = si, color = 'grey')
 ax1.text(38., 4.74, '4 Myr', fontsize = si, color = 'grey')
 ax1.text(38.8, 4.82, '6 Myr', fontsize = si, color = 'grey')
 ax1.text(39.2, 4.93, '8 Myr', fontsize = si, color = 'grey')

# Kiel
 ax111.text(34.5, 4.29, 'ZAMS', fontsize = si, color = 'grey')
 ax111.text(32.7, 4.13, '2 Myr', fontsize = si, color = 'grey')
 ax111.text(32.5, 4.03, '4 Myr', fontsize = si, color = 'grey')
 ax111.text(31, 3.87, '6 Myr', fontsize = si, color = 'grey')
 ax111.text(26.5, 3.5, '8 Myr', fontsize = si, color = 'grey')

# Hunter: (for schemes)
 #ax3.text(370, 7.83, 'ZAMS', fontsize = si, color = 'grey')
 #ax3.text(280, 8.4, '2 Myr', fontsize = si, color = 'grey')
 #ax3.text(200, 8.7, '4 Myr', fontsize = si, color = 'grey')
 #ax3.text(120, 8.83, '6 Myr', fontsize = si, color = 'grey')
 #ax3.text(60.5, 8.9, '8 Myr', fontsize = si, color = 'grey')

# for Bp
 #ax3.text(390, 7.8, 'ZAMS', fontsize = 36, color = 'grey')
 #ax3.text(380, 7.9, '2 Myr', fontsize = 36, color = 'grey')
 #ax3.text(380, 8.2, '4 Myr', fontsize = 36, color = 'grey')
 #ax3.text(380, 8.35, '6 Myr', fontsize = 36, color = 'grey')
 #ax3.text(350, 8.5, '8 Myr', fontsize = 36, color = 'grey')

# ax1.text(23., 4.9, '10 Myr', fontsize = 26, color = 'grey')
# ax1.text(14., 3.25, '50 Myr', fontsize = 26, color = 'grey')

# iso texts for LMC
if Zini == 0.006 : 
 ax1.text(51.5, 5.85, 'ZAMS', fontsize = 20, color = 'grey')
 ax1.text(45., 5.95, '2 Myr', fontsize = 20, color = 'grey')
 ax1.text(36.5, 5.4, '4 Myr', fontsize = 20, color = 'grey')
 ax1.text(27.5, 5.4, '6 Myr', fontsize = 20, color = 'grey')
 ax1.text(26.5, 5.2, '8 Myr', fontsize = 20, color = 'grey')
 ax1.text(25., 4.9, '10 Myr', fontsize = 20, color = 'grey')
 ax1.text(16., 3.25, '50 Myr', fontsize = 20, color = 'grey')

# iso texts for SMC
if Zini == 0.002 : 
 ax1.text(55.5, 5.75, 'ZAMS', fontsize = 20, color = 'grey')
 ax1.text(50.5, 6.0, '2 Myr', fontsize = 20, color = 'grey')
 ax1.text(40.5, 5.45, '4 Myr', fontsize = 20, color = 'grey')
 ax1.text(31., 5.4, '6 Myr', fontsize = 20, color = 'grey')
 ax1.text(29.5, 5.2, '8 Myr', fontsize = 20, color = 'grey')
 ax1.text(26.5, 4.9, '10 Myr', fontsize = 20, color = 'grey')
 ax1.text(18., 3.3, '50 Myr', fontsize = 20, color = 'grey')

#=========
# for Z: 
ax3.text(390, 7.8, 'ZAMS', fontsize = 36, color = 'grey')
ax3.text(280, 7.9, '2 Myr', fontsize = 36, color = 'grey')
ax3.text(180, 8.06, '4 Myr', fontsize = 36, color = 'grey')
ax3.text(120, 8.15, '6 Myr', fontsize = 36, color = 'grey')
ax3.text(50, 8.25, '8 Myr', fontsize = 36, color = 'grey')

si2 = 40

legend = ax1.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='best', shadow=True, fontsize=si2, handlelength = 4)
legend = ax111.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='best', shadow=True, fontsize=si2, handlelength = 4)
legend = ax3.legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='best', shadow=True, fontsize=si2, handlelength = 4)
legend = ax4.legend(fancybox = True, scatterpoints =1, edgecolor = "black", facecolor = "orange", framealpha = 0.6, labelspacing = 1, loc='best', shadow=True, fontsize=si2, handlelength = 4)


fig1.tight_layout()
fig111.tight_layout()
fig3.tight_layout()
fig4.tight_layout()

fig1.savefig('FIDU/hrd/hrd'+modi+'.png')
fig111.savefig('FIDU/Kiel/kiel'+modi+'.png')
fig3.savefig('FIDU/Hunter/hunter'+modi+'.png')
fig4.savefig('FIDU/mass'+modi+'.png')
