'''
This python script is used to read in MESA evolutionary files 
and create the Hunter diagram (with observations) displayed in 
"Paper IV" by Keszthelyi et al. 

Have fun plotting, 
    Zsolt Keszthelyi, 2022
'''

import matplotlib.pyplot as plt
import matplotlib.ticker as ticker
from matplotlib.ticker import FormatStrFormatter
import numpy as np
import sys
import math
from pylab import *
from matplotlib.collections import PatchCollection
from matplotlib.patches import Rectangle
from matplotlib.collections import LineCollection
from matplotlib.ticker import AutoMinorLocator

#----------------------------------------------
sigma = 5.67051 * pow(10,-5)  # cgs
Rsun = 6.957 * pow(10,10)  # cgs
Lsun = 3.828 * pow(10,33)  # cgs
pi = np.pi
G = 6.67259e-8 # cgs
Msun = 1.99e33  # cgs
year = 3.154e7  # sec. 
Teffsun = 5.780e3 # K 
loggsun = 4.43775 # cgs
Lscriptsun = pow(Teffsun,4.)/(10**loggsun)
#=========================================
from plotsetup import *   
#=========================================
#
#==== MODELS
Zini = 0.0064
Zin = '6'
Bpinin = 3.0  # in kG
Bpini = '3000' 
mod = ['15.0','16.0','17.0', '18.0', '19.0', '20.0', '21.0', '22.0','23.0','24.0','25.0', '30.0', '40.0', '50.0', '60.0']
mes = '/LOGS/out.data'

mix = 'Mix1' 
scheme = 'INT'
path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme+'/Z'+Zin+mix+'/'+Bpini+'/'

mix2 = 'Mix2'
scheme2 = 'SURF' 
path2 = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme2+'/Z'+Zin+mix2+'/'+Bpini+'/'

mix4 = 'Mix1' 
scheme4 = 'SURF' 
path4 = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme4+'/Z'+Zin+mix4+'/'+Bpini+'/'

mix5 = 'Mix2' # or 'Mix2'
scheme5 = 'INT' # INT, SURF, NOMAG
path5 = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme5+'/Z'+Zin+mix5+'/'+Bpini+'/'

mix6 = 'Mix1' # or 'Mix2'
scheme6 = 'NOMAG' # INT, SURF, NOMAG
path6 = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme6+'/Z'+Zin+mix6+'/0/'

mix7 = 'Mix2' # or 'Mix2'
scheme7 = 'NOMAG' # INT, SURF, NOMAG
path7 = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/'+scheme7+'/Z'+Zin+mix7+'/0/'


#==== OBS

pathobs = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/obsd/'
datagr = np.genfromtxt(pathobs+'tab_grin17.txt', skip_header = 1)
datadu = np.genfromtxt(pathobs+'tab_dufton18.txt', skip_header = 1)

#mc_vrot = datamc[:,3]
#mc_lognit = datamc[:,9]
#mc_logg = datamc[:,5]
#mc_err = datamc[:,10]
#print np.average(mc_err)

gr_vrot = datagr[:,3]
gr_lognit = datagr[:,4]
gr_logg = datagr[:,7]

gr_err = datagr[:,5]
gr_err = abs(gr_err)

du_vrot = datadu[:,1]
du_lognit = datadu[:,6]
du_logg = datadu[:,3]

print( '--------------------------------------')
print( '--------------------------------------')
print(  min(gr_logg), min(du_logg))
print( '--------------------------------------')
print(  max(gr_logg), max(du_logg))
print( '--------------------------------------')
print('--------------------------------------')

# for testing local
#:path = '../data/'
#:mod = ['local/']
#:mes ='/LOGS/out.data'

num = len(mod)

k = ['navy','grey','green','yellow','blue','navy','grey','green','yellow','blue','navy','grey','green','yellow','blue','navy','grey','green','yellow','blue','navy','grey','green','yellow','blue']
j = [':','--','-.','-',':','--','-.','-','--','-.','-','--','-.']
lww = [6,6,6,12,12,12,18,18,18]

# This is for the colour bar:
# logg 


def get_max_bar_value():
    mm = 0
    for i in range(0,num):
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        logg =  data[x:,14]
        bar = logg
        m_temp = bar.max()
        if m_temp > mm:
            mm = m_temp          
    return mm
mm = get_max_bar_value()
bazz = mm 


def get_min_bar_value():
    nn = 1e33
    for i in range(0,num):
        data = np.genfromtxt(path+mod[i]+mes, skip_header = 6)
        coreh = data[:,59]    # center H1
        xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
        x = len(xd)
        logg =  data[x:,14]
        bar = logg
        n_temp = bar.min()
        if n_temp < nn:   
            nn = n_temp          
    return nn
nn = get_min_bar_value()
megg = nn 

print( '************************************************************')
print( '*   Thank you for plotting with python. Have a nice day.   *')
print( '************************************************************')

fig3, ax3 = plt.subplots(1,1, figsize=(20,16))
ax3.set_xlim(-40,330)
ax3.set_ylim(6.6,9.55)   # for Bp in G: 7.7, 9.2 for Z: GAL: 7.7, 8.25 LMC: 7.4, 8.3 SMC: 7.0, 8.5
#ax8.invert_xaxis()
ax3.set_xlabel('$v_{\mathrm{rot}} \sin i$ [km s$^{-1}$]',  size=60)
ax3.set_ylabel('log $[N/H] + 12$',  size=60)
ax3.tick_params(labelsize=44, width = 9, length = 22)
ax3.xaxis.set_minor_locator(AutoMinorLocator(5))
ax3.yaxis.set_minor_locator(AutoMinorLocator(5))
ax3.tick_params(which = 'minor', width = 3, length = 12)

##### MESA files input ###### 
#
#
for i in range(0,num) : 
 data = np.genfromtxt(path+mod[i]+mes,skip_header=6)  
 #-----------------------------------------------
 coreh = data[:,59]
 xd = coreh.compress((coreh>coreh[0]*0.997).flat) 
 x = len(xd)

 model = data[:,0]
 m = len(model)
 age2 = data[x-1:m-1,1]
 age = data[x:,1]
 M = data[x:,2]
 logM = np.log10(M)
 Mdot = data[x:,3]
 Mdot = - Mdot 
 logMdot = np.log10(Mdot)
 logTeff = data[x:,6]
 Teff = data[x:,7]
 logL = data[x:,11]
 R =  data[x:,13]
 logg =  data[x:,14]
 g = 10**logg
 centernit = data[x:,62] # N14
 logsurfh1 = data[x:,69]
 surfh1 = pow(10,logsurfh1)
 nit = data[x:,66] # N14
 ox = data[x:,67] # O16
 car = data[x:,65]  # C12
 lognit = np.log10(nit/(14*surfh1)) + 12
 logsurfhe = data[x:,70] # He4 surf
 surfhe = 10**logsurfhe
 #:::print surfhe[-1]
 
 nith = nit/surfh1
 oxh = ox/surfh1
 carh = car/surfh1

 #-- rot
 vrot = data[x:,22]
 Jtot = data[x:,5]
 Omega = data[x:,19]
 Omegac = data[x:,58]
 omdivomcr = data[x:,20]
 periods = 2. * pi * (R*Rsun) / (vrot *1e5)
 period = periods / (3600. * 24.)
 logperiod = np.log10(period)

# !!! 
# !!! 
# === SURF - Mix2 here === 
 data3 = np.genfromtxt(path2+mod[i]+mes,skip_header=6)  
 coreh3 = data3[:,59]
 xd3 = coreh3.compress((coreh3>coreh3[0]*0.997).flat) 
 x3 = len(xd3)
 R3 =  data3[x3:,13]
 vrot3 = data3[x3:,22]
 logg3 =  data3[x3:,14]
 periods3 = 2. * pi * (R3*Rsun) / (vrot3 *1e5)
 period3 = periods3 / (3600. * 24.)
 logperiod3 = np.log10(period3)
 logsurfh13 = data3[x3:,69]
 surfh13 = pow(10,logsurfh13)
 nit3 = data3[x3:,66] # N14
 lognit3 = np.log10(nit3/(14*surfh13)) + 12
#==========================
# !!! 
# !!! 

# !!! 
# !!! 
# === SURF - Mix1 here === 
 data4 = np.genfromtxt(path4+mod[i]+mes,skip_header=6)  
 coreh4 = data4[:,59]
 xd4 = coreh4.compress((coreh4>coreh4[0]*0.997).flat) 
 x4 = len(xd4)
 R4 =  data4[x4:,13]
 vrot4 = data4[x4:,22]
 logg4 =  data4[x4:,14]
 periods4 = 2. * pi * (R4*Rsun) / (vrot4 *1e5)
 period4 = periods4 / (3600. * 24.)
 logperiod4 = np.log10(period4)
 logsurfh14 = data4[x4:,69]
 surfh14 = pow(10,logsurfh14)
 nit4 = data4[x4:,66] # N14
 lognit4 = np.log10(nit4/(14*surfh14)) + 12
#==========================
# !!! 
# !!! 

# !!! 
# !!! 
# === INT - Mix2 here === 
 data5 = np.genfromtxt(path5+mod[i]+mes,skip_header=6)  
 coreh5 = data5[:,59]
 xd5 = coreh5.compress((coreh5>coreh5[0]*0.997).flat) 
 x5 = len(xd5)
 R5 =  data5[x5:,13]
 vrot5 = data5[x5:,22]
 logg5 =  data5[x5:,14]
 periods5 = 2. * pi * (R5*Rsun) / (vrot5 *1e5)
 period5 = periods5 / (3600. * 24.)
 logperiod5 = np.log10(period5)
 logsurfh15 = data5[x5:,69]
 surfh15 = pow(10,logsurfh15)
 nit5 = data5[x5:,66] # N14
 lognit5 = np.log10(nit5/(14*surfh15)) + 12
#==========================
# !!! 
# !!! 


# !!! 
# !!! 
# === NOMAG - Mix1 here === 
 data6 = np.genfromtxt(path6+mod[i]+mes,skip_header=6)  
 coreh6 = data6[:,59]
 xd6 = coreh6.compress((coreh6>coreh6[0]*0.997).flat) 
 x6 = len(xd6)
 R6 =  data6[x6:,13]
 vrot6 = data6[x6:,22]
 logg6 =  data6[x6:,14]
 periods6 = 2. * pi * (R6*Rsun) / (vrot6 *1e5)
 period6 = periods6 / (3600. * 24.)
 logperiod6 = np.log10(period6)
 logsurfh16 = data6[x6:,69]
 surfh16 = pow(10,logsurfh16)
 nit6 = data6[x6:,66] # N14
 lognit6 = np.log10(nit6/(14*surfh16)) + 12


#==========================
# !!! 
# !!! 

# !!! 
# !!! 
# === NOMAG - Mix2 here === 
 data7 = np.genfromtxt(path7+mod[i]+mes,skip_header=6)  
 coreh7 = data7[:,59]
 xd7 = coreh7.compress((coreh7>coreh7[0]*0.997).flat) 
 x7 = len(xd7)
 R7 =  data7[x7:,13]
 vrot7 = data7[x7:,22]
 logg7 =  data7[x7:,14]
 periods7 = 2. * pi * (R7*Rsun) / (vrot7 *1e5)
 period7 = periods7 / (3600. * 24.)
 logperiod7 = np.log10(period7)
 logsurfh17 = data7[x7:,69]
 surfh17 = pow(10,logsurfh17)
 nit7 = data7[x7:,66] # N14
 lognit7 = np.log10(nit7/(14*surfh17)) + 12
 # decrease the numerical noise
# simple test case: 
# vrotsav7 = vrot7[::15]
# lognitsav7 = lognit7[::15]
# smoothing used:
 n_smooth = 21
 bound = int(np.fix((n_smooth-1)/2))
 lognitsav7 = lognit7[bound:len(lognit7)-bound]
 vrotsav7 = np.zeros(len(vrot7)-n_smooth+1)
 for j in range(bound,len(vrot7)-bound):
   vrotsav7[j-bound] = np.mean(vrot7[j:j+n_smooth-1])
#==========================

#::::::::::::::::::::::::::::::::::::::::::::::::::::::::

#=========  END of MESA file input ==============================================================

 Mini = "{:1.0f}".format(M[0])
 scale1 = - np.log10(logg/max(logg)) * 2500
 #print scale1 
 #scale2 = - np.log10(mc_logg/max(gr_logg)) * 2900
 scale3 = - np.log10(gr_logg/max(gr_logg)) * 2900
 scale4 = - np.log10(du_logg/max(gr_logg)) * 2900
 scale5 = - np.log10(4/max(gr_logg)) * 2900
 scale6 = - np.log10(3/max(gr_logg)) * 2900

# === IN LOOP PLOTS ===    
 cmapp = plt.cm.gist_rainbow

# HUNTER INT Mix1
# ax3.plot(vrot * math.sin(math.radians(45)), lognit, lw=1, linestyle = '-', color =  'grey', zorder = 60 )
 ims3 = ax3.scatter(vrot * math.sin(math.radians(45)), lognit,c= logg, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 30-i)

# SURF Mix2 
# ax3.plot(vrot3 * math.sin(math.radians(45)), lognit3, lw=1, linestyle = '-', color =  'grey', zorder = 60 )
 ims3 = ax3.scatter(vrot3 * math.sin(math.radians(45)), lognit3,c= logg3, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 30-i)
 
# SURF Mix1 
 ax3.plot(vrot4 * math.sin(math.radians(45)), lognit4, lw=1, linestyle = '-', color =  'white', zorder = 60 )
 ims3 = ax3.scatter(vrot4 * math.sin(math.radians(45)), lognit4,c= logg4, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 60-i)
 
# INT Mix2
# ax3.plot(vrot5 * math.sin(math.radians(45))., lognit5, lw=1, linestyle = '-', color =  'grey', zorder = 60 )
 ims3 = ax3.scatter(vrot5 * math.sin(math.radians(45)), lognit5,c= logg5, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 30-i)
 
 # NOMAG Mix1
 ax3.plot(vrot6 * math.sin(math.radians(45)), lognit6, lw=1, linestyle = '-', color =  'black', zorder = 60 )

# ims3 = ax3.scatter(vrot5 * math.sin(math.radians(45)), lognit5,c= logg5, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 30-i)
 
# NOMAG Mix2
 #::: ax3.plot(vrot7 * math.sin(math.radians(45)), lognit7, lw=1, linestyle = '-', color =  'gold', zorder = 60, alpha = 0.4 )
# ims3 = ax3.scatter(vrot5 * math.sin(math.radians(45)), lognit5,c= logg5, marker='o', edgecolors='none', s=300, cmap=cmapp, vmin = 3.0, vmax = 4.5, zorder = 30-i)
 ax3.plot(vrotsav7 * math.sin(math.radians(45)), lognitsav7, lw=1, linestyle = '-', color =  'grey', zorder = 65 )


 if i < 1 :  
    ax3.text(vrot[-1] * math.sin(math.radians(45)) - 45, lognit[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
    ax3.text(vrot3[-1] * math.sin(math.radians(45)) - 45, lognit3[-1]  , Mini, fontsize = 36, zorder = 44)
    ax3.text(vrot5[-1] * math.sin(math.radians(45)) - 40, lognit5[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
    #ax3.text(vrot5[-1] * math.sin(math.radians(45)) - 35, lognit5[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
   

 if i > 13 :  
    ax3.text(vrot[-1] * math.sin(math.radians(45)) - 29, lognit[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
    ax3.text(vrot3[-1] * math.sin(math.radians(45)) - 29, lognit3[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
    ax3.text(vrot5[-1] * math.sin(math.radians(45)) - 29, lognit5[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)
   # ax3.text(vrot5[-1] * math.sin(math.radians(45)) - 35, lognit5[-1] - 0.02 , Mini, fontsize = 36, zorder = 44)


# if i < 5 : 
#  ax3.text(vrot[-1]*np.pi/4. - 25, lognit[-1], Mini, fontsize = 16)

# ===  OBS ===
 
#--ax3.scatter(mc_vrot, mc_lognit, marker='s', s= 900,edgecolors='black', linewidth = 5, c = mc_logg, zorder=100, cmap=cmapp, vmin = 3.0, vmax = max(gr_logg))
# obs w vsini > 300 are not shown. (few stars)

ax3.scatter(gr_vrot, gr_lognit, marker='o', s= 900,edgecolors='black', linewidth = 5, c = gr_logg, zorder=110, cmap=cmapp, vmin = 3.0, vmax = 4.5) 
ax3.scatter(du_vrot, du_lognit, marker='s', s= 900,edgecolors='black', linewidth = 5, c = du_logg, zorder=120, cmap=cmapp, vmin = 3.0, vmax = 4.5)

#--ax3.scatter(0, 0, marker='s', s=800,color = 'black', zorder=110, label = 'McEvoy+2015')
ax3.scatter(0, 0, marker='o', s=800,color = 'black', zorder=110, label = 'Grin+2017')
ax3.scatter(0, 0, marker='s', s=800,color = 'black', zorder=110, label = 'Dufton+2018')

# COLOR BARS 

cbar = fig3.colorbar(ims3)
cbar.ax.tick_params(labelsize=54) 
cbar.set_label('log $g$ [cm s$^{-2}$]', size = 54)

# +++++++++++++++++++++++++++++++++++++++++++++++
# FINISH PLOTS:
# BOX and TEXT 
# +++++++++++++++++++++++++++++++++++++++++++++++

ax3.text(140, 7.02, 'INT/Mix1', fontsize = 32)
ax3.text(0, 8.34, 'INT/Mix2', fontsize = 32)
ax3.text(112, 8.18, 'SURF/Mix1', fontsize = 32, zorder = 99)
ax3.text(0, 8.75, 'SURF/\nMix2', fontsize = 32, zorder = 99)
ax3.text(275, 7.6, 'NOMAG/\nMix1', fontsize = 32)
ax3.text(120, 8.9, 'NOMAG/Mix2', fontsize = 32, color = 'grey')
ax3.text(270, 7.0, 'ZAMS', fontsize = 38)

ax3.fill([-4,54,54,-4],[7.25,7.25,9.55,9.55], hatch='', edgecolor='black', linewidth = 6, color = 'blue', fill=True, alpha = 0.2)

strg = '\n'.join(('$B_{eq, ini} = $ %s kG', '$Z_{ini} = $ %s')) % (Bpinin, Zini)
 
ax3.text(65, 9.22, strg, bbox=dict(facecolor='white', alpha=0.5, boxstyle='round'), fontsize = 38, color = 'black')

legend = ax3.legend(fancybox = True, scatterpoints =1, labelspacing = 0.5, loc='upper right', shadow=True, fontsize=34, handlelength = 2)
fig3.tight_layout()
fig3.savefig('Z'+Zin+'Om5/Huntobs/hunter'+Bpini+'OBS_FINAL.png')
