'''
Process the MESA outputs for archival
Sam Geen, January 2022
'''

import glob, os

DEBUG = True
errlog = open("../logcopyerrors.txt","w")

def is_number(string):
    try:
        float(string)
        # Hack to remove 2 Msun test models
        if string == "2.0":
            return False
        return True
    except ValueError:
        return False

def filternumbers(inlist):
    # Filter a list of folders to find only folders that are numbers
    return list(filter(lambda x: is_number(x[x.rfind("/")+1:]), inlist))

def copyfile(source,destination):
    # Run copy command, with debug option to just print it
    global DEBUG
    #print(source, destination)
    # Check that file exists
    if not os.path.exists(source):
        errlog.write("NO FILE WITH NAME "+source+" \n")
        #raise OSError
    # Run command
    cmd = "cp "+source+" "+destination
    if DEBUG:
        #print(cmd)
        pass
    else:
        os.system(cmd)

def makefolders(folder):
    # Make folder structure if not already made, with debug option to just print it
    try:
        if DEBUG:
            #print(folder)
            pass
        else:
            os.makedirs(folder)
    except:
        pass

def processstar(starfolder):
    # Process a single star model folder
    #print(starfolder)
    proftarget = starfolder.replace("../","../PROFILES/")+"/"
    evoltarget = starfolder.replace("../","../EVOLUTION/")+"/"
    modtarget = starfolder.replace("../","../MOD/")+"/"
    makefolders(proftarget)
    makefolders(evoltarget)
    # Process structure profiles
    copyfile(starfolder+"/LOGS/prof_TAMS.data",proftarget)
    copyfile(starfolder+"/LOGS/prof_ZAMS.data",proftarget)
    copyfile(starfolder+"/LOGS/prof_midMS.data",proftarget)
    copyfile(starfolder+"/LOGS/out.data",evoltarget)
    copyfile(starfolder+"/TAMS.mod",modtarget)

def runforsuite(rootfolder):
    # Run for a named suite of data by diving into the data folders
    models = glob.glob("../"+rootfolder+"/*")
    # LEVEL 1: Which model to use (Metallicity + Mixing)
    for model in models:
        print("Running for model", model)
        # Get folders which have numbers in them
        Bfields = glob.glob(model+"/*")
        Bfields = filternumbers(Bfields)
        # LEVEL 2: B FIELD
        for Bfield in Bfields:
            stars = glob.glob(Bfield+"/*")
            stars = filternumbers(stars)
            # LEVEL 3: STELLAR MASSES
            for star in stars:
                processstar(star)

def runall():
    runforsuite("INT")  # SURF, NOMAG

if __name__=="__main__":
    runall()
    errlog.close()
