'''
This python script is used to create structure plots, displayed in 
"Paper IV" by Keszthelyi et al. 
Other diagnostics can also easily be set up with this architecture. 

Have fun plotting, 
    Zsolt Keszthelyi, 2022
'''

import sys
import numpy as np
import matplotlib.ticker
from matplotlib.ticker import FormatStrFormatter
import matplotlib.pyplot as plt
from pylab import *
from matplotlib.ticker import AutoMinorLocator
from astropy.convolution import Box1DKernel

bscheme = 2 # or 0,1,2 for NOMAG, INT or SURF braking! 
mscheme = 1 # or 2 for Chemical Mixing! 

#=================
which = 3    # ZAMS, mid-MS, or TAMS
#=================
if which ==1 : 
 print ('**********')
 print ('ZAMS model')
 print ('**********')
if which ==2 : 
 print ('**********')
 print ('mid-MS model')
 print ('**********')
if which ==3 : 
 print ('**********')
 print ('TAMS model')
 print ('**********')
#=================


# load from file
name = []  
# === for grid ===
#:::field = [500, 1000, 2000, 3000, 4000, 5000, 6000, 7000, 8000, 9000, 10000, 11000, 12000, 13000, 14000, 15000, 20000, 25000, 30000, 50000]
#:::mass = ['5.0', '6.0', '7.0', '8.0', '9.0', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '30', '40', '50', '60', '80']
#path = '../data/Z014Om5Mix2/'
#----
if mscheme == 1 and bscheme == 0 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/NOMAG/Z14Mix1/'
if mscheme == 2 and bscheme == 0 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/NOMAG/Z14Mix2/'
if mscheme == 1 and bscheme == 1 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/INT/Z14Mix1/'
if mscheme == 1 and bscheme == 2 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/SURF/Z14Mix1/'
if mscheme == 2 and bscheme == 1 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/INT/Z14Mix2/'
if mscheme == 2 and bscheme == 2 : 
 path = '/Volumes/Macintosh HD/Volumes/Extz/zsolt/RESEARCH/MESA/Grid/data/SURF/Z14Mix2/'

# === for local ===
#path = '../'
#field = 'local/'
#mass = 'LOGS/'
#==================

# === for grid ==== 
if bscheme == 1 or bscheme == 2:
   field = '3000/'
if bscheme == 0: 
   field = '0/' # for nomag
mass = '20.0/LOGS/'   # remember 3.0 format

# initial 
rc('axes', linewidth=9)

fig1, ax1 = plt.subplots(1,2, figsize=(35,10))
#log_formatter = matplotlib.ticker.LogFormatterExponent()
ax1[0].set_yscale("log")
ax1[0].set_xlim(0,1.05)
#ax1[0].yaxis.set_major_formatter(log_formatter)
ax1[0].tick_params(labelsize=36, width = 5, length = 22)
ax1[0].xaxis.set_minor_locator(AutoMinorLocator(5))
#ax1.yaxis.set_minor_locator(AutoMinorLocator(5))
ax1[0].tick_params(which = 'minor', width = 3, length = 12)
ax1[0].set_ylabel('$\log$ D $[\mathrm{cm}^2\,\mathrm{s}^{-1}]$', size=44 )
ax1[0].set_xlabel(' m / M$_\star$', size=44 )

# Abundance
#ax1[1].set_yscale("log")
#-ax1.yaxis.set_major_formatter(log_formatter)
#ax1[1].tick_params(labelsize=36, width = 5, length = 22)
#ax1[1].xaxis.set_minor_locator(AutoMinorLocator(5))
#-ax1.yaxis.set_minor_locator(AutoMinorLocator(5))
#ax1[1].tick_params(which = 'minor', width = 3, length = 12)
#ax1[1].set_ylabel('$\log$ Abundances', size=44 )

ax1[1].set_yscale("log")
#ax1.yaxis.set_major_formatter(log_formatter)

ax1[1].tick_params(labelsize=36, width = 5, length = 22, axis = 'x')
ax1[1].tick_params(labelsize=36, width = 5, length = 22, axis = 'y', colors = 'blue', which = 'both')
ax1[1].tick_params(which = 'minor', width = 3, length = 12)
ax1[1].xaxis.set_minor_locator(AutoMinorLocator(5))
ax1#--[1].yaxis.set_minor_locator(AutoMinorLocator(5))

ax1[1].set_ylabel('$\log$ $j$ [cm$^2$ s$^{-1}$] ', size=44, color = 'blue' )

ax1[1].set_xlabel(' m / M$_\star$', size=44 )


if mscheme == 1 and bscheme == 0: 
   ax1[0].set_title('NOMAG/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('NOMAG/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)
if mscheme == 2 and bscheme == 0: 
   ax1[0].set_title('NOMAG/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('NOMAG/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)

if mscheme == 1 and bscheme == 1: 
   ax1[0].set_title('INT/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('INT/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)
#   ax1[1].set_title('Mix1 Scheme', size=30)
if mscheme == 2 and bscheme == 2: 
   ax1[0].set_title('SURF/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('SURF/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)
#   ax1[1].set_title('Mix2 Scheme', size=30)
if bscheme == 1 and mscheme == 2: 
   ax1[0].set_title('INT/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('INT/Mix2 scheme', size=34, fontweight = 'bold', pad = 30)
if bscheme == 2 and mscheme == 1: 
   ax1[0].set_title('SURF/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)
   ax1[1].set_title('SURF/Mix1 scheme', size=34, fontweight = 'bold', pad = 30)

# 
if which == 1 : 
 data = np.genfromtxt(path+field+mass+'prof_ZAMS.data', skip_header = 6)
 datal = np.genfromtxt(path+field+mass+'prof_ZAMS.data', skip_header = 2, usecols = 4)
 datah = np.genfromtxt(path+field+mass+'prof_ZAMS.data', skip_header = 2, usecols = 10)
 datat = np.genfromtxt(path+field+mass+'prof_ZAMS.data', skip_header = 2, usecols = 5)
# 
if which == 2 :
 data = np.genfromtxt(path+field+mass+'prof_midMS.data', skip_header = 6)
 datal = np.genfromtxt(path+field+mass+'prof_midMS.data', skip_header = 2, usecols = 4)
 datah = np.genfromtxt(path+field+mass+'prof_midMS.data', skip_header = 2, usecols = 10)
 datat = np.genfromtxt(path+field+mass+'prof_midMS.data', skip_header = 2, usecols = 5)
#  
if which == 3 :
 data = np.genfromtxt(path+field+mass+'prof_TAMS.data', skip_header = 6)
 datal = np.genfromtxt(path+field+mass+'prof_TAMS.data', skip_header = 2, usecols = 4)
 datah = np.genfromtxt(path+field+mass+'prof_TAMS.data', skip_header = 2, usecols = 10)
 datat = np.genfromtxt(path+field+mass+'prof_TAMS.data', skip_header = 2, usecols = 5)
# 

# === MESA parameters === 

if which == 1 or which == 2 or which == 3: 
 xmr = data[:,17] 
 le = len(xmr)
 
 ma = max(data[:,62])
 mass = "{:1.0f}".format(ma)
 
# --- stuff from 3rd row 
 ag = int(datal[:1])
 age = "{:1.2f}".format(ag/1e6) # in Myr
 hcont = float(datah[:1])
 hcontent = "{:1.4f}".format(hcont)
 dt = float(datat[:1])
# --- 
 gradL = data[:,59]
 mu = data[:,16]
 omega = data[:,82]
 jrot = data[:,86]
 logomega = np.log10(omega)
 nablamu = data[:,60] #? 
 extrajdot = data[:,96]
 extraj = extrajdot * dt # specific angular momentum lost

# diffusion coefficients & their friends
 Dconv = data[:,44]
 Dov = data[:,46]

# STANDARD MESA FILE: 
 DSI = data[:,49]
 DSH = data[:,50]
 DSSI = data[:,51]
 DES = data[:,52]
 DGSF = data[:,53]
 DST = data[:,54]
 AMST = data[:,55]

 bs1 = data[:,90]
 bs2 = data[:,91]
 bs3 = data[:,92]
 
 # only in SURF models
 if bscheme == 2: 
    bs5 = data[:,102]

 bs1 = pow(10,bs1)
 bs2 = pow(10,bs2)
 bs3 = pow(10,bs3)

 DSSI = pow(10,DSSI)
 DSI = pow(10,DSI)
 DSH = pow(10,DSH)
 DES = pow(10,DES)
 DGSF = pow(10,DGSF)
 DST = pow(10,DST)
 AMST = pow(10,AMST)
 
 # some little smooting of noisy data
 n_smooth = 21   # 21, 31, 41, 61
 bound = int(np.fix((n_smooth-1)/2))

 bs3_smooth = np.zeros(len(bs3)-n_smooth+1)
 bs5_smooth = np.zeros(len(bs5)-n_smooth+1)
 DGSF_smooth = np.zeros(len(DGSF)-n_smooth+1)
 DES_smooth = np.zeros(len(DES)-n_smooth+1)
 xmr_smooth = xmr[bound:len(xmr)-bound]
 for i in range(bound,len(DES)-bound):
   DES_smooth[i-bound] = np.mean(DES[i:i+n_smooth-1])
 for i in range(bound,len(DGSF)-bound):
   DGSF_smooth[i-bound] = np.mean(DGSF[i:i+n_smooth-1])
 for i in range(bound,len(bs3)-bound):
   bs3_smooth[i-bound] = np.mean(bs3[i:i+n_smooth-1])
 for i in range(bound,len(bs5)-bound):
   bs5_smooth[i-bound] = np.mean(bs5[i:i+n_smooth-1])

 Dconv = pow(10,Dconv)
 Dov = pow(10,Dov)

 mod_D_shear = data[:,97]
 mod_dlnomega_dlnr = data[:,99] 
 mod_U = data[:,98]
 mod_D_eff = data[:,100]
 
 Dconv_smooth = np.zeros(len(Dconv)-n_smooth+1)
 mod_D_shear_smooth = np.zeros(len(mod_D_shear)-n_smooth+1)
 mod_D_eff_smooth = np.zeros(len(mod_D_eff)-n_smooth+1)
 for i in range(bound,len(mod_D_shear)-bound):
   mod_D_shear_smooth[i-bound] = np.mean(mod_D_shear[i:i+n_smooth-1])
 for i in range(bound,len(mod_D_eff)-bound):
   mod_D_eff_smooth[i-bound] = np.mean(mod_D_eff[i:i+n_smooth-1])
 for i in range(bound,len(Dconv)-bound):
   Dconv_smooth[i-bound] = np.mean(Dconv[i:i+n_smooth-1])

# abundance stuff
 h = data[:,71]
 he = data[:,73]
 c = data[:,74]
 n = data[:,75]
 o = data[:,76]

# don't show Deff for conv region. 
 for i in range(0,le) : 
  if mod_D_eff[i] < Dconv[i]:
   mod_D_eff[i] = 0.0
 for j in range(0,len(mod_D_eff_smooth)):
  if mod_D_eff_smooth[j] < Dconv_smooth[j]:
   mod_D_eff_smooth[j] = 0.0

# === plot === 

wi = 11   
fc = 0.033

if which == 1 or which == 2 or which == 3: 

 ax1[0].plot(xmr,Dconv,label="$D_{\mathrm{conv}}$", linewidth = wi, color = 'grey')
 ax1[0].plot(xmr,Dov,label="$D_{\mathrm{ov}}$", linewidth = wi, color = 'orange',zorder = 3)
 
  # NOMAG Mix1
 if mscheme == 1 and bscheme == 0 : 
 #: ax1[0].plot(xmr,fc * DSI,label="$D_{\mathrm{DSI}}$", linewidth = wi, color = 'lime', zorder = 2)
  ax1[0].plot(xmr,fc * DSSI, linewidth = wi, color = 'green', label="$D_{\mathrm{SSI}}$", zorder = 44)
  ax1[0].plot(xmr,fc * DSH, linewidth = wi, color = 'purple', zorder = 44)  # label="$D_{\mathrm{SH}}$",
  #ax1[0].plot(xmr,fc * DES,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red')
  #ax1[0].plot(xmr,fc * DGSF,label="$D_{\mathrm{GSF}}$", linewidth = wi, color = 'navy')
  ax1[0].plot(xmr_smooth,fc * DES_smooth,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red', zorder = 11)
  ax1[0].plot(xmr_smooth,fc * DGSF_smooth,label="$D_{\mathrm{GSF}}$", linewidth = 5, color = 'navy',zorder = 22)

 # Mix1 & SURF
 if mscheme == 1 and bscheme == 2 : 
 # ax1[0].plot(xmr,fc * DSI,label="$D_{\mathrm{DSI}}$", linewidth = wi, color = 'lime', zorder = 2)
 # CHECK in which case shears are relevant:
  ax1[0].plot(xmr,fc * DSSI, linewidth = wi, color = 'green', zorder = 44, label="$D_{\mathrm{SSI}}$")
  ax1[0].plot(xmr,fc * DSH, linewidth = wi, color = 'purple', zorder = 44)  # label="$D_{\mathrm{SH}}$",
  #ax1[0].plot(xmr,fc * DES,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red')
  #ax1[0].plot(xmr,fc * DGSF,label="$D_{\mathrm{GSF}}$", linewidth = wi, color = 'navy')
  ax1[0].plot(xmr_smooth,fc * DES_smooth,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red', zorder = 11)
  ax1[0].plot(xmr_smooth,fc * DGSF_smooth,label="$D_{\mathrm{GSF}}$", linewidth = 5, color = 'navy',zorder = 22)

  # Mix1 & INT
 if mscheme == 1 and bscheme == 1 : 
  ax1[0].plot(xmr,fc * DSI, linewidth = wi, color = 'lime', zorder = 44)
  #ax1[0].plot(xmr,fc * DSSI, linewidth = wi, color = 'green', zorder = 44)  # label="$D_{\mathrm{SSI}}$",
  ax1[0].plot(xmr,fc * DSH, linewidth = wi, color = 'purple', zorder = 44)  # label="$D_{\mathrm{SH}}$",
  #ax1[0].plot(xmr,fc * DES,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red')
  #ax1[0].plot(xmr,fc * DGSF,label="$D_{\mathrm{GSF}}$", linewidth = wi, color = 'navy')
  ax1[0].plot(xmr_smooth,fc * DES_smooth,label="$D_{\mathrm{ES}}$", linewidth = wi, color = 'red', zorder = 11)
  ax1[0].plot(xmr_smooth,fc * DGSF_smooth,label="$D_{\mathrm{GSF}}$", linewidth = 5, color = 'navy',zorder = 22)


 # NOMAG Mix2 
 if mscheme == 2 and bscheme == 0 : 
  ax1[0].plot(xmr,mod_D_shear,label="$D_{\mathrm{shear}}$", linewidth = wi, color = 'green', zorder = 3)
  ax1[0].plot(xmr,mod_D_eff,label="$D_{\mathrm{eff}}$", linewidth = wi, color = 'pink', zorder = 5)

 # Mix2 & SURF 
 if mscheme == 2 and bscheme == 2 : 
  #ax1[0].plot(xmr,mod_D_shear,label="$D_{\mathrm{shear}}$", linewidth = wi, color = 'green', zorder = 3)
  #ax1[0].plot(xmr,mod_D_eff,label="$D_{\mathrm{eff}}$", linewidth = wi, color = 'pink', zorder = 5)
  ax1[0].plot(xmr_smooth,mod_D_shear_smooth,label="$D_{\mathrm{shear}}$", linewidth = wi, color = 'green', zorder = 3)
  ax1[0].plot(xmr_smooth,mod_D_eff_smooth,label="$D_{\mathrm{eff}}$", linewidth = wi, color = 'pink', zorder = 5)
 
  # Mix2 & INT
 if mscheme == 2 and bscheme == 1 : 
  ax1[0].plot(xmr,mod_D_shear,linewidth = wi, color = 'green', zorder = 3)
  ax1[0].plot(xmr,mod_D_eff,label="$D_{\mathrm{eff}}$", linewidth = wi, color = 'pink', zorder = 5)
 

 if bscheme == 0 : 
    ax1[0].plot(xmr_smooth,bs3_smooth,label="$D_{\mathrm{AM}}$", linewidth = wi, linestyle = ':', color = 'black', zorder = 66)
 if bscheme == 1 : 
    ax1[0].plot(xmr,bs1,label="$D_{\mathrm{AM}}$", linewidth = wi, linestyle = ':', color = 'black', zorder = 66)
 if bscheme == 2 : 
    ax1[0].plot(xmr_smooth,bs5_smooth,label="$D_{\mathrm{AM}}$", linewidth = wi, linestyle = ':', color = 'black', zorder = 66)


# more 
 ax10 = ax1[0].twinx()
 ax10.tick_params(labelsize=36, width = 5, length = 22, axis = 'y', colors = 'magenta', which = 'both')
 ax10.plot(xmr,mu,label="$'r'\mu$", linewidth = wi, color = 'magenta', zorder = 3)
 if which != 3 :
   ax10.set_ylim(0.6,1.0) 
 if which == 3: 
  ax10.set_ylim(0.6,1.4) 
 ax10.set_ylabel("$\mu$", size=44, color = 'magenta')
 ax10.yaxis.set_minor_locator(AutoMinorLocator(5))
 ax10.tick_params(which = 'minor', width = 3, length = 6)

# 2nd figure
 ax1[1].plot(xmr,jrot,label="j", linewidth = wi, color = 'blue', zorder = 3)
 #---ax1[2].plot(xmr,jrot+extraj,label="j losing", linewidth = wi, linestyle = ":")

#ln8 = ax1.plot(xmr,Kther,label="$K_{\mathrm{ther}}$", linewidth = wi)
lines2,labels2 = ax1[0].get_legend_handles_labels()
fill_min = np.zeros(le) + [0.00001]
ax1[0].fill_between(xmr,Dconv,fill_min, where=Dconv>fill_min,facecolor='grey', color = 'grey')
ax1[0].fill_between(xmr,Dov,fill_min, where=Dov>fill_min,facecolor='orange', color = 'orange',zorder = 3)
#ax1.fill_between(xmr,DmagO,fill_min, where=DmagO>fill_min,facecolor='blue', color = 'blue')
#ax1.fill_between(xmr,DmagX,fill_min, where=DmagX>fill_min,facecolor='cyan', color = 'cyan')
#ax1[0].fill_between(xmr,mod_D_shear,fill_min, where=mod_D_shear>fill_min,facecolor='green', color = 'orange',zorder = 5)

# more 
ax11 = ax1[1].twinx()
ax11.tick_params(labelsize=36, width = 5, length = 22)

#log_formatter = matplotlib.ticker.LogFormatterExponent()

if which != 3 :
   # Omega and j axes
   ax11.set_ylim(-6.1,-3.99)
   ax1[1].set_ylim(1e15,1e20) # (1e12,1e20) # (1e15,1e20)
if which == 3: 
   ax11.set_ylim(-7.5,-3.99)
   ax1[1].set_ylim(1e12,1e20) # (1e12,1e20) # (1e15,1e20)

ax11.set_ylabel('$\log \Omega$ [$\mathrm{s}^{-1}$]', size=44 )
ax11.plot(xmr,logomega,"k-",label="log $\Omega$", linewidth = wi)
ax11.yaxis.set_minor_locator(AutoMinorLocator(5))
ax11.tick_params(which = 'minor', width = 3, length = 6)

#Om_line,Om_label = ax11.get_legend_handles_labels()
#lines2.append(Om_line[0])
#labels2.append(Om_label[0])
#ax11.legend(lines2,labels2, fancybox = True, loc = 'lower left', fontsize = 32, handlelength = 2)

#ax1.set_xlim(0.,1.01)

# chem mix. 
ax1[0].set_ylim(1e-1,1e19)
#ax11.set_ylim(-5.5,-2.5)
legend = ax1[0].legend(loc = 'upper center', bbox_to_anchor = (1.3,0.5), ncol = 1, fancybox = True, scatterpoints =1, labelspacing = 1, shadow=True, fontsize=36, handlelength = 2)
#-legend = ax1[1].legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='lower left', shadow=True, fontsize=14, handlelength = 2)
#:::legend = ax1[2].legend(fancybox = True, scatterpoints =1, labelspacing = 1, loc='center right', shadow=True, fontsize=14, handlelength = 2)

#ttl = plt.title(mass+'M$_\odot$ '+age+'Myr '+'H:'+hcontent, size = 44)
fig1.suptitle(mass+'M$_\odot$  t:'+age+'Myr  '+'$X_{c}$:'+hcontent, size = 40, x = 0.5, y = 1.1, color = 'black')
#::ttl.set_position([.5, 1.03])
plt.tight_layout()
fig1.savefig('str_Z14Om5/'+str(which)+'M'+str(mscheme)+'B'+str(bscheme)+'.png', bbox_inches='tight') 



